@@ -45,25 +45,27 @@ namespace lsp
                 // Self algorithm
                 ARCH_ARM_ASM(
                     // Do bit-reverse shuffle
-                    __ASM_EMIT("rsb         %[rrank], %[rrank], $32")           // rrank = 32 - rank
-                    __ASM_EMIT("mov         %[i], $1")                          // i = 1
+                    __ASM_EMIT("rsb         %[rrank], %[rrank], #32")           // rrank = 32 - rank
+                    __ASM_EMIT("mov         %[i], #1")                          // i = 1
 
                     __ASM_EMIT("1:")
                 #if defined(ARCH_ARM6)
-                    __ASM_EMIT("push        {%[dst_re], %[dst_im]}")
+                    __ASM_EMIT("push        {%[dst_re]}")
+                    __ASM_EMIT("push        {%[dst_im]}")
                     LSP_ARMV6_MV_RBIT32("%[j]", "%[i]", "%[dst_re]", "%[dst_im]", "%[masks]") // j = reverse_bits(i)
-                    __ASM_EMIT("pop         {%[dst_re], %[dst_im]}")
+                    __ASM_EMIT("pop         {%[dst_im]}")
+                    __ASM_EMIT("pop         {%[dst_re]}")
                 #else
                     __ASM_EMIT("rbit        %[j], %[i]")                        // j = reverse_bits(i)
                 #endif
-                    __ASM_EMIT("add         %[src_re], $4")
+                    __ASM_EMIT("add         %[src_re], #4")
                     __ASM_EMIT("lsr         %[j], %[rrank]")                    // j = reverse_bits(i) >> rank
-                    __ASM_EMIT("add         %[src_im], $4")
+                    __ASM_EMIT("add         %[src_im], #4")
                     __ASM_EMIT("cmp         %[i], %[j]")                        // i <=> j
                     __ASM_EMIT("bhs         2f")                                // if (i >= j) continue
-                    __ASM_EMIT("add         %[d_re], %[dst_re], %[j], LSL $2")  // d_re = &dst_re[j]
+                    __ASM_EMIT("add         %[d_re], %[dst_re], %[j], LSL #2")  // d_re = &dst_re[j]
                     __ASM_EMIT("vldm        %[src_re], {s0}")                   // s0 = *src_re
-                    __ASM_EMIT("add         %[d_im], %[dst_im], %[j], LSL $2")  // d_im = &dst_im[j]
+                    __ASM_EMIT("add         %[d_im], %[dst_im], %[j], LSL #2")  // d_im = &dst_im[j]
                     __ASM_EMIT("vldm        %[src_im], {s1}")                   // s1 = *src_im
                     __ASM_EMIT("vldm        %[d_re], {s2}")                     // s2 = *td_re
                     __ASM_EMIT("vldm        %[d_im], {s3}")                     // s3 = *td_im
@@ -72,7 +74,7 @@ namespace lsp
                     __ASM_EMIT("vstm        %[d_re], {s0}")                     // *d_re = s0
                     __ASM_EMIT("vstm        %[d_im], {s1}")                     // *d_im = s1
                     __ASM_EMIT("2:")
-                    __ASM_EMIT("add         %[i], $1")                          // i++
+                    __ASM_EMIT("add         %[i], #1")                          // i++
                     __ASM_EMIT("cmp         %[i], %[count]")                    // i <=> count
                     __ASM_EMIT("blo         1b")
 
@@ -106,7 +108,7 @@ namespace lsp
                     __ASM_EMIT("vuzp.32     q0, q1")                            // q0 = i0" i1" i2" i3", q1 = i4" i5" i6" i7"
 
                     __ASM_EMIT("vst1.32     {q2-q3}, [%[dst_re]]!")
-                    __ASM_EMIT("subs        %[count], $8")                      // i <=> count
+                    __ASM_EMIT("subs        %[count], #8")                      // i <=> count
                     __ASM_EMIT("vst1.32     {q0-q1}, [%[dst_im]]!")
                     __ASM_EMIT("bne         3b")
 
@@ -131,49 +133,51 @@ namespace lsp
 
                 ARCH_ARM_ASM(
                     __ASM_EMIT("eor         %[i], %[i]")                         // i = 0
-                    __ASM_EMIT("rsb         %[rrank], %[rrank], $32")           // rrank = 32 - rank
+                    __ASM_EMIT("rsb         %[rrank], %[rrank], #32")           // rrank = 32 - rank
 
                     __ASM_EMIT("1:")
                 #if defined(ARCH_ARM6)
-                    __ASM_EMIT("push        {%[dst_re], %[dst_im]}")
+                    __ASM_EMIT("push        {%[dst_re]}")
+                    __ASM_EMIT("push        {%[dst_im]}")
                     LSP_ARMV6_MV_RBIT32("%[j]", "%[i]", "%[dst_re]", "%[dst_im]", "%[masks]") // j = reverse_bits(i)
-                    __ASM_EMIT("pop         {%[dst_re], %[dst_im]}")
+                    __ASM_EMIT("pop         {%[dst_im]}")
+                    __ASM_EMIT("pop         {%[dst_re]}")
                 #else
                     __ASM_EMIT("rbit        %[j], %[i]")                        // j = reverse_bits(i)
                 #endif
                     __ASM_EMIT("lsr         %[j], %[rrank]")                    // j = reverse_bits(i) >> rank
 
-                    __ASM_EMIT("add         %[s_re], %[src_re], %[j], LSL $2")  // s_re = &src_re[i]
-                    __ASM_EMIT("add         %[s_im], %[src_im], %[j], LSL $2")  // s_re = &src_im[i]
+                    __ASM_EMIT("add         %[s_re], %[src_re], %[j], LSL #2")  // s_re = &src_re[i]
+                    __ASM_EMIT("add         %[s_im], %[src_im], %[j], LSL #2")  // s_re = &src_im[i]
                     __ASM_EMIT("vldm        %[s_re], {s0}")                     // q0 = r0 ? ? ?
                     __ASM_EMIT("vldm        %[s_im], {s8}")                     // q2 = i0 ? ? ?
-                    __ASM_EMIT("add         %[s_re], %[s_re], %[regs], LSL $2") // s_re = &src_re[i + regs]
-                    __ASM_EMIT("add         %[s_im], %[s_im], %[regs], LSL $2") // s_re = &src_im[i + regs]
+                    __ASM_EMIT("add         %[s_re], %[s_re], %[regs], LSL #2") // s_re = &src_re[i + regs]
+                    __ASM_EMIT("add         %[s_im], %[s_im], %[regs], LSL #2") // s_re = &src_im[i + regs]
                     __ASM_EMIT("vldm        %[s_re], {s2}")                     // q0 = r0 ? r4 ?
                     __ASM_EMIT("vldm        %[s_im], {s10}")                    // q2 = i0 ? i4 ?
-                    __ASM_EMIT("add         %[s_re], %[s_re], %[regs], LSL $2") // s_re = &src_re[i + regs*2]
-                    __ASM_EMIT("add         %[s_im], %[s_im], %[regs], LSL $2") // s_re = &src_im[i + regs*2]
+                    __ASM_EMIT("add         %[s_re], %[s_re], %[regs], LSL #2") // s_re = &src_re[i + regs*2]
+                    __ASM_EMIT("add         %[s_im], %[s_im], %[regs], LSL #2") // s_re = &src_im[i + regs*2]
                     __ASM_EMIT("vldm        %[s_re], {s1}")                     // q0 = r0 r2 r4 ?
                     __ASM_EMIT("vldm        %[s_im], {s9}")                     // q2 = i0 i2 i4 ?
-                    __ASM_EMIT("add         %[s_re], %[s_re], %[regs], LSL $2") // s_re = &src_re[i + regs*3]
-                    __ASM_EMIT("add         %[s_im], %[s_im], %[regs], LSL $2") // s_re = &src_im[i + regs*3]
+                    __ASM_EMIT("add         %[s_re], %[s_re], %[regs], LSL #2") // s_re = &src_re[i + regs*3]
+                    __ASM_EMIT("add         %[s_im], %[s_im], %[regs], LSL #2") // s_re = &src_im[i + regs*3]
                     __ASM_EMIT("vldm        %[s_re], {s3}")                     // q0 = r0 r2 r4 r6
                     __ASM_EMIT("vldm        %[s_im], {s11}")                    // q2 = i0 i2 i4 i6
 
-                    __ASM_EMIT("add         %[s_re], %[s_re], %[regs], LSL $2") // s_re = &src_re[i + regs*4]
-                    __ASM_EMIT("add         %[s_im], %[s_im], %[regs], LSL $2") // s_re = &src_im[i + regs*4]
+                    __ASM_EMIT("add         %[s_re], %[s_re], %[regs], LSL #2") // s_re = &src_re[i + regs*4]
+                    __ASM_EMIT("add         %[s_im], %[s_im], %[regs], LSL #2") // s_re = &src_im[i + regs*4]
                     __ASM_EMIT("vldm        %[s_re], {s4}")                     // q1 = r1 ? ? ?
                     __ASM_EMIT("vldm        %[s_im], {s12}")                    // q3 = i1 ? ? ?
-                    __ASM_EMIT("add         %[s_re], %[s_re], %[regs], LSL $2") // s_re = &src_re[i + regs*5]
-                    __ASM_EMIT("add         %[s_im], %[s_im], %[regs], LSL $2") // s_re = &src_im[i + regs*5]
+                    __ASM_EMIT("add         %[s_re], %[s_re], %[regs], LSL #2") // s_re = &src_re[i + regs*5]
+                    __ASM_EMIT("add         %[s_im], %[s_im], %[regs], LSL #2") // s_re = &src_im[i + regs*5]
                     __ASM_EMIT("vldm        %[s_re], {s6}")                     // q1 = r1 ? r5 ?
                     __ASM_EMIT("vldm        %[s_im], {s14}")                    // q3 = i1 ? i5 ?
-                    __ASM_EMIT("add         %[s_re], %[s_re], %[regs], LSL $2") // s_re = &src_re[i + regs*6]
-                    __ASM_EMIT("add         %[s_im], %[s_im], %[regs], LSL $2") // s_re = &src_im[i + regs*6]
+                    __ASM_EMIT("add         %[s_re], %[s_re], %[regs], LSL #2") // s_re = &src_re[i + regs*6]
+                    __ASM_EMIT("add         %[s_im], %[s_im], %[regs], LSL #2") // s_re = &src_im[i + regs*6]
                     __ASM_EMIT("vldm        %[s_re], {s5}")                     // q1 = r1 r3 r5 ?
                     __ASM_EMIT("vldm        %[s_im], {s13}")                    // q3 = i1 i3 i5 ?
-                    __ASM_EMIT("add         %[s_re], %[s_re], %[regs], LSL $2") // s_re = &src_re[i + regs*7]
-                    __ASM_EMIT("add         %[s_im], %[s_im], %[regs], LSL $2") // s_re = &src_im[i + regs*7]
+                    __ASM_EMIT("add         %[s_re], %[s_re], %[regs], LSL #2") // s_re = &src_re[i + regs*7]
+                    __ASM_EMIT("add         %[s_im], %[s_im], %[regs], LSL #2") // s_re = &src_im[i + regs*7]
                     __ASM_EMIT("vldm        %[s_re], {s7}")                     // q1 = r1 r3 r5 r7
                     __ASM_EMIT("vldm        %[s_im], {s15}")                    // q3 = i1 i3 i5 i7
 
@@ -181,7 +185,7 @@ namespace lsp
                     // q1 = r1 r3 r5 r7
                     // q2 = i0 i2 i4 i6
                     // q3 = i1 i3 i5 i7
-                    __ASM_EMIT("add         %[i], $1")
+                    __ASM_EMIT("add         %[i], #1")
 
                     // Perform x8 butterflies
                     __ASM_EMIT("vadd.f32    q4, q0, q1")                        // q4 = r0+r1 r2+r3 r4+r5 r6+r7 = r0' r2' r4' r6'
@@ -239,25 +243,27 @@ namespace lsp
                 // Self algorithm
                 ARCH_ARM_ASM(
                     // Do bit-reverse shuffle
-                    __ASM_EMIT("rsb         %[rrank], %[rrank], $32")           // rrank = 32 - rank
-                    __ASM_EMIT("mov         %[i], $1")                          // i = 1
+                    __ASM_EMIT("rsb         %[rrank], %[rrank], #32")           // rrank = 32 - rank
+                    __ASM_EMIT("mov         %[i], #1")                          // i = 1
 
                     __ASM_EMIT("1:")
                 #if defined(ARCH_ARM6)
-                    __ASM_EMIT("push        {%[dst_re], %[dst_im]}")
+                    __ASM_EMIT("push        {%[dst_re]}")
+                    __ASM_EMIT("push        {%[dst_im]}")
                     LSP_ARMV6_MV_RBIT32("%[j]", "%[i]", "%[dst_re]", "%[dst_im]", "%[masks]") // j = reverse_bits(i)
-                    __ASM_EMIT("pop         {%[dst_re], %[dst_im]}")
+                    __ASM_EMIT("pop         {%[dst_im]}")
+                    __ASM_EMIT("pop         {%[dst_re]}")
                 #else
                     __ASM_EMIT("rbit        %[j], %[i]")                        // j = reverse_bits(i)
                 #endif
-                    __ASM_EMIT("add         %[src_re], $4")
+                    __ASM_EMIT("add         %[src_re], #4")
                     __ASM_EMIT("lsr         %[j], %[rrank]")                    // j = reverse_bits(i) >> rank
-                    __ASM_EMIT("add         %[src_im], $4")
+                    __ASM_EMIT("add         %[src_im], #4")
                     __ASM_EMIT("cmp         %[i], %[j]")                        // i <=> j
                     __ASM_EMIT("bhs         2f")                                // if (i >= j) continue
-                    __ASM_EMIT("add         %[d_re], %[dst_re], %[j], LSL $2")  // d_re = &dst_re[j]
+                    __ASM_EMIT("add         %[d_re], %[dst_re], %[j], LSL #2")  // d_re = &dst_re[j]
                     __ASM_EMIT("vldm        %[src_re], {s0}")                   // s0 = *src_re
-                    __ASM_EMIT("add         %[d_im], %[dst_im], %[j], LSL $2")  // d_im = &dst_im[j]
+                    __ASM_EMIT("add         %[d_im], %[dst_im], %[j], LSL #2")  // d_im = &dst_im[j]
                     __ASM_EMIT("vldm        %[src_im], {s1}")                   // s1 = *src_im
                     __ASM_EMIT("vldm        %[d_re], {s2}")                     // s2 = *td_re
                     __ASM_EMIT("vldm        %[d_im], {s3}")                     // s3 = *td_im
@@ -266,7 +272,7 @@ namespace lsp
                     __ASM_EMIT("vstm        %[d_re], {s0}")                     // *d_re = s0
                     __ASM_EMIT("vstm        %[d_im], {s1}")                     // *d_im = s1
                     __ASM_EMIT("2:")
-                    __ASM_EMIT("add         %[i], $1")                          // i++
+                    __ASM_EMIT("add         %[i], #1")                          // i++
                     __ASM_EMIT("cmp         %[i], %[count]")                    // i <=> count
                     __ASM_EMIT("blo         1b")
 
@@ -302,7 +308,7 @@ namespace lsp
                     __ASM_EMIT("vuzp.32     q0, q1")                            // q0 = i0" i1" i2" i3", q1 = i4" i5" i6" i7"
 
                     __ASM_EMIT("vst1.32     {q2-q3}, [%[dst_re]]!")
-                    __ASM_EMIT("subs        %[count], $8")                      // i <=> count
+                    __ASM_EMIT("subs        %[count], #8")                      // i <=> count
                     __ASM_EMIT("vst1.32     {q0-q1}, [%[dst_im]]!")
                     __ASM_EMIT("bne         3b")
 
@@ -327,49 +333,51 @@ namespace lsp
 
                 ARCH_ARM_ASM(
                     __ASM_EMIT("eor         %[i], %[i]")                         // i = 0
-                    __ASM_EMIT("rsb         %[rrank], %[rrank], $32")           // rrank = 32 - rank
+                    __ASM_EMIT("rsb         %[rrank], %[rrank], #32")           // rrank = 32 - rank
 
                     __ASM_EMIT("1:")
                 #if defined(ARCH_ARM6)
-                    __ASM_EMIT("push        {%[dst_re], %[dst_im]}")
+                    __ASM_EMIT("push        {%[dst_re]}")
+                    __ASM_EMIT("push        {%[dst_im]}")
                     LSP_ARMV6_MV_RBIT32("%[j]", "%[i]", "%[dst_re]", "%[dst_im]", "%[masks]") // j = reverse_bits(i)
-                    __ASM_EMIT("pop         {%[dst_re], %[dst_im]}")
+                    __ASM_EMIT("pop         {%[dst_im]}")
+                    __ASM_EMIT("pop         {%[dst_re]}")
                 #else
                     __ASM_EMIT("rbit        %[j], %[i]")                        // j = reverse_bits(i)
                 #endif
                     __ASM_EMIT("lsr         %[j], %[rrank]")                    // j = reverse_bits(i) >> rank
 
-                    __ASM_EMIT("add         %[s_re], %[src_re], %[j], LSL $2")  // s_re = &src_re[i]
-                    __ASM_EMIT("add         %[s_im], %[src_im], %[j], LSL $2")  // s_re = &src_im[i]
+                    __ASM_EMIT("add         %[s_re], %[src_re], %[j], LSL #2")  // s_re = &src_re[i]
+                    __ASM_EMIT("add         %[s_im], %[src_im], %[j], LSL #2")  // s_re = &src_im[i]
                     __ASM_EMIT("vldm        %[s_re], {s0}")                     // q0 = r0 ? ? ?
                     __ASM_EMIT("vldm        %[s_im], {s8}")                     // q2 = i0 ? ? ?
-                    __ASM_EMIT("add         %[s_re], %[s_re], %[regs], LSL $2") // s_re = &src_re[i + regs]
-                    __ASM_EMIT("add         %[s_im], %[s_im], %[regs], LSL $2") // s_re = &src_im[i + regs]
+                    __ASM_EMIT("add         %[s_re], %[s_re], %[regs], LSL #2") // s_re = &src_re[i + regs]
+                    __ASM_EMIT("add         %[s_im], %[s_im], %[regs], LSL #2") // s_re = &src_im[i + regs]
                     __ASM_EMIT("vldm        %[s_re], {s2}")                     // q0 = r0 ? r4 ?
                     __ASM_EMIT("vldm        %[s_im], {s10}")                    // q2 = i0 ? i4 ?
-                    __ASM_EMIT("add         %[s_re], %[s_re], %[regs], LSL $2") // s_re = &src_re[i + regs*2]
-                    __ASM_EMIT("add         %[s_im], %[s_im], %[regs], LSL $2") // s_re = &src_im[i + regs*2]
+                    __ASM_EMIT("add         %[s_re], %[s_re], %[regs], LSL #2") // s_re = &src_re[i + regs*2]
+                    __ASM_EMIT("add         %[s_im], %[s_im], %[regs], LSL #2") // s_re = &src_im[i + regs*2]
                     __ASM_EMIT("vldm        %[s_re], {s1}")                     // q0 = r0 r2 r4 ?
                     __ASM_EMIT("vldm        %[s_im], {s9}")                     // q2 = i0 i2 i4 ?
-                    __ASM_EMIT("add         %[s_re], %[s_re], %[regs], LSL $2") // s_re = &src_re[i + regs*3]
-                    __ASM_EMIT("add         %[s_im], %[s_im], %[regs], LSL $2") // s_re = &src_im[i + regs*3]
+                    __ASM_EMIT("add         %[s_re], %[s_re], %[regs], LSL #2") // s_re = &src_re[i + regs*3]
+                    __ASM_EMIT("add         %[s_im], %[s_im], %[regs], LSL #2") // s_re = &src_im[i + regs*3]
                     __ASM_EMIT("vldm        %[s_re], {s3}")                     // q0 = r0 r2 r4 r6
                     __ASM_EMIT("vldm        %[s_im], {s11}")                    // q2 = i0 i2 i4 i6
 
-                    __ASM_EMIT("add         %[s_re], %[s_re], %[regs], LSL $2") // s_re = &src_re[i + regs*4]
-                    __ASM_EMIT("add         %[s_im], %[s_im], %[regs], LSL $2") // s_re = &src_im[i + regs*4]
+                    __ASM_EMIT("add         %[s_re], %[s_re], %[regs], LSL #2") // s_re = &src_re[i + regs*4]
+                    __ASM_EMIT("add         %[s_im], %[s_im], %[regs], LSL #2") // s_re = &src_im[i + regs*4]
                     __ASM_EMIT("vldm        %[s_re], {s4}")                     // q1 = r1 ? ? ?
                     __ASM_EMIT("vldm        %[s_im], {s12}")                    // q3 = i1 ? ? ?
-                    __ASM_EMIT("add         %[s_re], %[s_re], %[regs], LSL $2") // s_re = &src_re[i + regs*5]
-                    __ASM_EMIT("add         %[s_im], %[s_im], %[regs], LSL $2") // s_re = &src_im[i + regs*5]
+                    __ASM_EMIT("add         %[s_re], %[s_re], %[regs], LSL #2") // s_re = &src_re[i + regs*5]
+                    __ASM_EMIT("add         %[s_im], %[s_im], %[regs], LSL #2") // s_re = &src_im[i + regs*5]
                     __ASM_EMIT("vldm        %[s_re], {s6}")                     // q1 = r1 ? r5 ?
                     __ASM_EMIT("vldm        %[s_im], {s14}")                    // q3 = i1 ? i5 ?
-                    __ASM_EMIT("add         %[s_re], %[s_re], %[regs], LSL $2") // s_re = &src_re[i + regs*6]
-                    __ASM_EMIT("add         %[s_im], %[s_im], %[regs], LSL $2") // s_re = &src_im[i + regs*6]
+                    __ASM_EMIT("add         %[s_re], %[s_re], %[regs], LSL #2") // s_re = &src_re[i + regs*6]
+                    __ASM_EMIT("add         %[s_im], %[s_im], %[regs], LSL #2") // s_re = &src_im[i + regs*6]
                     __ASM_EMIT("vldm        %[s_re], {s5}")                     // q1 = r1 r3 r5 ?
                     __ASM_EMIT("vldm        %[s_im], {s13}")                    // q3 = i1 i3 i5 ?
-                    __ASM_EMIT("add         %[s_re], %[s_re], %[regs], LSL $2") // s_re = &src_re[i + regs*7]
-                    __ASM_EMIT("add         %[s_im], %[s_im], %[regs], LSL $2") // s_re = &src_im[i + regs*7]
+                    __ASM_EMIT("add         %[s_re], %[s_re], %[regs], LSL #2") // s_re = &src_re[i + regs*7]
+                    __ASM_EMIT("add         %[s_im], %[s_im], %[regs], LSL #2") // s_re = &src_im[i + regs*7]
                     __ASM_EMIT("vldm        %[s_re], {s7}")                     // q1 = r1 r3 r5 r7
                     __ASM_EMIT("vldm        %[s_im], {s15}")                    // q3 = i1 i3 i5 i7
 
@@ -377,7 +385,7 @@ namespace lsp
                     // q1 = r1 r3 r5 r7
                     // q2 = i0 i2 i4 i6
                     // q3 = i1 i3 i5 i7
-                    __ASM_EMIT("add         %[i], $1")
+                    __ASM_EMIT("add         %[i], #1")
 
                     // Perform x8 butterflies
                     __ASM_EMIT("vadd.f32    q4, q0, q1")                        // q4 = r0+r1 r2+r3 r4+r5 r6+r7 = r0' r2' r4' r6'
