@@ -37,7 +37,7 @@ namespace lsp
                 __ASM_EMIT("vdup.32     q15, %y[k2]")
                 __ASM_EMIT("vmov        q14, q15")
                 __ASM_EMIT("vmov        q12, q13")
-                __ASM_EMIT("subs        %[count], $16")
+                __ASM_EMIT("subs        %[count], #16")
                 __ASM_EMIT("bls         2f")
                 /* 16x blocks */
                 __ASM_EMIT("1:")
@@ -51,12 +51,12 @@ namespace lsp
                 __ASM_EMIT("vmla.f32    q1, q5, q15")
                 __ASM_EMIT("vmla.f32    q2, q6, q14")
                 __ASM_EMIT("vmla.f32    q3, q7, q15")
-                __ASM_EMIT("subs        %[count], $16")
+                __ASM_EMIT("subs        %[count], #16")
                 __ASM_EMIT("vstm        %[a]!, {q0-q3}")
                 __ASM_EMIT("bhs         1b")
                 /* 8x block */
                 __ASM_EMIT("2:")
-                __ASM_EMIT("adds        %[count], $8")
+                __ASM_EMIT("adds        %[count], #8")
                 __ASM_EMIT("blt         4f")
                 __ASM_EMIT("vldm        %[a], {q0-q1}")
                 __ASM_EMIT("vldm        %[b]!, {q4-q5}")
@@ -64,28 +64,28 @@ namespace lsp
                 __ASM_EMIT("vmul.f32    q1, q13")
                 __ASM_EMIT("vmla.f32    q0, q4, q14")
                 __ASM_EMIT("vmla.f32    q1, q5, q15")
-                __ASM_EMIT("sub         %[count], $8")
+                __ASM_EMIT("sub         %[count], #8")
                 __ASM_EMIT("vstm        %[a]!, {q0-q1}")
                 /* 4x block */
                 __ASM_EMIT("4:")
-                __ASM_EMIT("adds        %[count], $4")
+                __ASM_EMIT("adds        %[count], #4")
                 __ASM_EMIT("blt         6f")
                 __ASM_EMIT("vldm        %[a], {q0}")
                 __ASM_EMIT("vldm        %[b]!, {q4}")
                 __ASM_EMIT("vmul.f32    q0, q12")
                 __ASM_EMIT("vmla.f32    q0, q4, q14")
-                __ASM_EMIT("sub         %[count], $4")
+                __ASM_EMIT("sub         %[count], #4")
                 __ASM_EMIT("vstm        %[a]!, {q0}")
                 /* 1x blocks */
                 __ASM_EMIT("6:")
-                __ASM_EMIT("adds        %[count], $3")
+                __ASM_EMIT("adds        %[count], #3")
                 __ASM_EMIT("blt         8f")
                 __ASM_EMIT("7:")
                 __ASM_EMIT("vld1.32     {d0[], d1[]}, [%[a]]")
                 __ASM_EMIT("vld1.32     {d8[], d9[]}, [%[b]]!")
                 __ASM_EMIT("vmul.f32    q0, q12")
                 __ASM_EMIT("vmla.f32    q0, q4, q14")
-                __ASM_EMIT("subs        %[count], $1")
+                __ASM_EMIT("subs        %[count], #1")
                 __ASM_EMIT("vst1.32     {d0[0]}, [%[a]]!")
                 __ASM_EMIT("bge         7b")
                 /* End */
@@ -109,7 +109,7 @@ namespace lsp
                 __ASM_EMIT("vdup.32     q15, %y[k2]")
                 __ASM_EMIT("vmov        q14, q15")
                 __ASM_EMIT("vmov        q12, q13")
-                __ASM_EMIT("subs        %[count], $16")
+                __ASM_EMIT("subs        %[count], #16")
                 __ASM_EMIT("bls         2f")
                 /* 16x blocks */
                 __ASM_EMIT("1:")
@@ -123,12 +123,12 @@ namespace lsp
                 __ASM_EMIT("vmla.f32    q1, q5, q15")
                 __ASM_EMIT("vmla.f32    q2, q6, q14")
                 __ASM_EMIT("vmla.f32    q3, q7, q15")
-                __ASM_EMIT("subs        %[count], $16")
+                __ASM_EMIT("subs        %[count], #16")
                 __ASM_EMIT("vstm        %[dst]!, {q0-q3}")
                 __ASM_EMIT("bhs         1b")
                 /* 8x block */
                 __ASM_EMIT("2:")
-                __ASM_EMIT("adds        %[count], $8")
+                __ASM_EMIT("adds        %[count], #8")
                 __ASM_EMIT("blt         4f")
                 __ASM_EMIT("vldm        %[a]!, {q0-q1}")
                 __ASM_EMIT("vldm        %[b]!, {q4-q5}")
@@ -136,28 +136,28 @@ namespace lsp
                 __ASM_EMIT("vmul.f32    q1, q13")
                 __ASM_EMIT("vmla.f32    q0, q4, q14")
                 __ASM_EMIT("vmla.f32    q1, q5, q15")
-                __ASM_EMIT("sub         %[count], $8")
+                __ASM_EMIT("sub         %[count], #8")
                 __ASM_EMIT("vstm        %[dst]!, {q0-q1}")
                 /* 4x block */
                 __ASM_EMIT("4:")
-                __ASM_EMIT("adds        %[count], $4")
+                __ASM_EMIT("adds        %[count], #4")
                 __ASM_EMIT("blt         6f")
                 __ASM_EMIT("vldm        %[a]!, {q0}")
                 __ASM_EMIT("vldm        %[b]!, {q4}")
                 __ASM_EMIT("vmul.f32    q0, q12")
                 __ASM_EMIT("vmla.f32    q0, q4, q14")
-                __ASM_EMIT("sub         %[count], $4")
+                __ASM_EMIT("sub         %[count], #4")
                 __ASM_EMIT("vstm        %[dst]!, {q0}")
                 /* 1x blocks */
                 __ASM_EMIT("6:")
-                __ASM_EMIT("adds        %[count], $3")
+                __ASM_EMIT("adds        %[count], #3")
                 __ASM_EMIT("blt         8f")
                 __ASM_EMIT("7:")
                 __ASM_EMIT("vld1.32     {d0[], d1[]}, [%[a]]!")
                 __ASM_EMIT("vld1.32     {d8[], d9[]}, [%[b]]!")
                 __ASM_EMIT("vmul.f32    q0, q12")
                 __ASM_EMIT("vmla.f32    q0, q4, q14")
-                __ASM_EMIT("subs        %[count], $1")
+                __ASM_EMIT("subs        %[count], #1")
                 __ASM_EMIT("vst1.32     {d0[0]}, [%[dst]]!")
                 __ASM_EMIT("bge         7b")
                 /* end */
@@ -181,7 +181,7 @@ namespace lsp
                 __ASM_EMIT("vdup.32     q15, %y[k2]")
                 __ASM_EMIT("vmov        q14, q15")
                 __ASM_EMIT("vmov        q12, q13")
-                __ASM_EMIT("subs        %[count], $16")
+                __ASM_EMIT("subs        %[count], #16")
                 __ASM_EMIT("bls         2f")
                 /* 16x blocks */
                 __ASM_EMIT("1:")
@@ -196,12 +196,12 @@ namespace lsp
                 __ASM_EMIT("vmla.f32    q9, q5, q15")
                 __ASM_EMIT("vmla.f32    q10, q6, q14")
                 __ASM_EMIT("vmla.f32    q11, q7, q15")
-                __ASM_EMIT("subs        %[count], $16")
+                __ASM_EMIT("subs        %[count], #16")
                 __ASM_EMIT("vstm        %[dst]!, {q8-q11}")
                 __ASM_EMIT("bhs         1b")
                 /* 8x block */
                 __ASM_EMIT("2:")
-                __ASM_EMIT("adds        %[count], $8")
+                __ASM_EMIT("adds        %[count], #8")
                 __ASM_EMIT("blt         4f")
                 __ASM_EMIT("vldm        %[dst], {q8-q9}")
                 __ASM_EMIT("vldm        %[a]!, {q0-q1}")
@@ -210,22 +210,22 @@ namespace lsp
                 __ASM_EMIT("vmla.f32    q9, q1, q13")
                 __ASM_EMIT("vmla.f32    q8, q4, q14")
                 __ASM_EMIT("vmla.f32    q9, q5, q15")
-                __ASM_EMIT("sub         %[count], $8")
+                __ASM_EMIT("sub         %[count], #8")
                 __ASM_EMIT("vstm        %[dst]!, {q8-q9}")
                 /* 4x block */
                 __ASM_EMIT("4:")
-                __ASM_EMIT("adds        %[count], $4")
+                __ASM_EMIT("adds        %[count], #4")
                 __ASM_EMIT("blt         6f")
                 __ASM_EMIT("vldm        %[dst], {q8}")
                 __ASM_EMIT("vldm        %[a]!, {q0}")
                 __ASM_EMIT("vldm        %[b]!, {q4}")
                 __ASM_EMIT("vmla.f32    q8, q0, q12")
                 __ASM_EMIT("vmla.f32    q8, q4, q14")
-                __ASM_EMIT("sub         %[count], $4")
+                __ASM_EMIT("sub         %[count], #4")
                 __ASM_EMIT("vstm        %[dst]!, {q8}")
                 /* 1x blocks */
                 __ASM_EMIT("6:")
-                __ASM_EMIT("adds        %[count], $3")
+                __ASM_EMIT("adds        %[count], #3")
                 __ASM_EMIT("blt         8f")
                 __ASM_EMIT("7:")
                 __ASM_EMIT("vld1.32     {d16[], d17[]}, [%[dst]]")
@@ -233,7 +233,7 @@ namespace lsp
                 __ASM_EMIT("vld1.32     {d8[], d9[]}, [%[b]]!")
                 __ASM_EMIT("vmla.f32    q8, q0, q12")
                 __ASM_EMIT("vmla.f32    q8, q4, q14")
-                __ASM_EMIT("subs        %[count], $1")
+                __ASM_EMIT("subs        %[count], #1")
                 __ASM_EMIT("vst1.32     {d16[0]}, [%[dst]]!")
                 __ASM_EMIT("bge         7b")
                 /* end */
@@ -256,7 +256,7 @@ namespace lsp
                 __ASM_EMIT("vdup.32     q13, %y[k1]")
                 __ASM_EMIT("vdup.32     q14, %y[k2]")
                 __ASM_EMIT("vdup.32     q15, %y[k3]")
-                __ASM_EMIT("subs        %[count], $16")
+                __ASM_EMIT("subs        %[count], #16")
                 __ASM_EMIT("bls         2f")
                 /* 16x blocks */
                 __ASM_EMIT("1:")
@@ -275,12 +275,12 @@ namespace lsp
                 __ASM_EMIT("vmla.f32    q1, q9, q15")
                 __ASM_EMIT("vmla.f32    q2, q10, q15")
                 __ASM_EMIT("vmla.f32    q3, q11, q15")
-                __ASM_EMIT("subs        %[count], $16")
+                __ASM_EMIT("subs        %[count], #16")
                 __ASM_EMIT("vstm        %[a]!, {q0-q3}")
                 __ASM_EMIT("bhs         1b")
                 /* 8x block */
                 __ASM_EMIT("2:")
-                __ASM_EMIT("adds        %[count], $8")
+                __ASM_EMIT("adds        %[count], #8")
                 __ASM_EMIT("blt         4f")
                 __ASM_EMIT("vldm        %[a], {q0-q1}")
                 __ASM_EMIT("vldm        %[b]!, {q4-q5}")
@@ -291,11 +291,11 @@ namespace lsp
                 __ASM_EMIT("vmla.f32    q1, q5, q14")
                 __ASM_EMIT("vmla.f32    q0, q8, q15")
                 __ASM_EMIT("vmla.f32    q1, q9, q15")
-                __ASM_EMIT("sub         %[count], $8")
+                __ASM_EMIT("sub         %[count], #8")
                 __ASM_EMIT("vstm        %[a]!, {q0-q1}")
                 /* 4x block */
                 __ASM_EMIT("4:")
-                __ASM_EMIT("adds        %[count], $4")
+                __ASM_EMIT("adds        %[count], #4")
                 __ASM_EMIT("blt         6f")
                 __ASM_EMIT("vldm        %[a], {q0}")
                 __ASM_EMIT("vldm        %[b]!, {q4}")
@@ -303,11 +303,11 @@ namespace lsp
                 __ASM_EMIT("vmul.f32    q0, q0, q13")
                 __ASM_EMIT("vmla.f32    q0, q4, q14")
                 __ASM_EMIT("vmla.f32    q0, q8, q15")
-                __ASM_EMIT("sub         %[count], $4")
+                __ASM_EMIT("sub         %[count], #4")
                 __ASM_EMIT("vstm        %[a]!, {q0}")
                 /* 1x blocks */
                 __ASM_EMIT("6:")
-                __ASM_EMIT("adds        %[count], $3")
+                __ASM_EMIT("adds        %[count], #3")
                 __ASM_EMIT("blt         8f")
                 __ASM_EMIT("7:")
                 __ASM_EMIT("vld1.32     {d0[], d1[]}, [%[a]]")
@@ -316,7 +316,7 @@ namespace lsp
                 __ASM_EMIT("vmul.f32    q0, q0, q13")
                 __ASM_EMIT("vmla.f32    q0, q4, q14")
                 __ASM_EMIT("vmla.f32    q0, q8, q15")
-                __ASM_EMIT("subs        %[count], $1")
+                __ASM_EMIT("subs        %[count], #1")
                 __ASM_EMIT("vst1.32     {d0[0]}, [%[a]]!")
                 __ASM_EMIT("bge         7b")
                 /* end */
@@ -339,7 +339,7 @@ namespace lsp
                 __ASM_EMIT("vdup.32     q13, %y[k1]")
                 __ASM_EMIT("vdup.32     q14, %y[k2]")
                 __ASM_EMIT("vdup.32     q15, %y[k3]")
-                __ASM_EMIT("subs        %[count], $16")
+                __ASM_EMIT("subs        %[count], #16")
                 __ASM_EMIT("bls         2f")
                 /* 16x blocks */
                 __ASM_EMIT("1:")
@@ -358,12 +358,12 @@ namespace lsp
                 __ASM_EMIT("vmla.f32    q1, q9, q15")
                 __ASM_EMIT("vmla.f32    q2, q10, q15")
                 __ASM_EMIT("vmla.f32    q3, q11, q15")
-                __ASM_EMIT("subs        %[count], $16")
+                __ASM_EMIT("subs        %[count], #16")
                 __ASM_EMIT("vstm        %[dst]!, {q0-q3}")
                 __ASM_EMIT("bhs         1b")
                 /* 8x block */
                 __ASM_EMIT("2:")
-                __ASM_EMIT("adds        %[count], $8")
+                __ASM_EMIT("adds        %[count], #8")
                 __ASM_EMIT("blt         4f")
                 __ASM_EMIT("vldm        %[a]!, {q0-q1}")
                 __ASM_EMIT("vldm        %[b]!, {q4-q5}")
@@ -374,11 +374,11 @@ namespace lsp
                 __ASM_EMIT("vmla.f32    q1, q5, q14")
                 __ASM_EMIT("vmla.f32    q0, q8, q15")
                 __ASM_EMIT("vmla.f32    q1, q9, q15")
-                __ASM_EMIT("sub         %[count], $8")
+                __ASM_EMIT("sub         %[count], #8")
                 __ASM_EMIT("vstm        %[dst]!, {q0-q1}")
                 /* 4x block */
                 __ASM_EMIT("4:")
-                __ASM_EMIT("adds        %[count], $4")
+                __ASM_EMIT("adds        %[count], #4")
                 __ASM_EMIT("blt         6f")
                 __ASM_EMIT("vldm        %[a]!, {q0}")
                 __ASM_EMIT("vldm        %[b]!, {q4}")
@@ -386,11 +386,11 @@ namespace lsp
                 __ASM_EMIT("vmul.f32    q0, q0, q13")
                 __ASM_EMIT("vmla.f32    q0, q4, q14")
                 __ASM_EMIT("vmla.f32    q0, q8, q15")
-                __ASM_EMIT("sub         %[count], $4")
+                __ASM_EMIT("sub         %[count], #4")
                 __ASM_EMIT("vstm        %[dst]!, {q0}")
                 /* 1x blocks */
                 __ASM_EMIT("6:")
-                __ASM_EMIT("adds        %[count], $3")
+                __ASM_EMIT("adds        %[count], #3")
                 __ASM_EMIT("blt         8f")
                 __ASM_EMIT("7:")
                 __ASM_EMIT("vld1.32     {d0[], d1[]}, [%[a]]!")
@@ -399,7 +399,7 @@ namespace lsp
                 __ASM_EMIT("vmul.f32    q0, q0, q13")
                 __ASM_EMIT("vmla.f32    q0, q4, q14")
                 __ASM_EMIT("vmla.f32    q0, q8, q15")
-                __ASM_EMIT("subs        %[count], $1")
+                __ASM_EMIT("subs        %[count], #1")
                 __ASM_EMIT("vst1.32     {d0[0]}, [%[dst]]!")
                 __ASM_EMIT("bge         7b")
                 /* end */
@@ -422,7 +422,7 @@ namespace lsp
                 __ASM_EMIT("vdup.32     q13, %y[k1]")
                 __ASM_EMIT("vdup.32     q14, %y[k2]")
                 __ASM_EMIT("vdup.32     q15, %y[k3]")
-                __ASM_EMIT("subs        %[count], $16")
+                __ASM_EMIT("subs        %[count], #16")
                 __ASM_EMIT("bls         2f")
                 /* 16x blocks */
                 __ASM_EMIT("1:")
@@ -442,12 +442,12 @@ namespace lsp
                 __ASM_EMIT("vmla.f32    q1, q5, q15")
                 __ASM_EMIT("vmla.f32    q2, q6, q15")
                 __ASM_EMIT("vmla.f32    q3, q7, q15")
-                __ASM_EMIT("subs        %[count], $16")
+                __ASM_EMIT("subs        %[count], #16")
                 __ASM_EMIT("vstm        %[dst]!, {q0-q3}")
                 __ASM_EMIT("bhs         1b")
                 /* 8x block */
                 __ASM_EMIT("2:")
-                __ASM_EMIT("adds        %[count], $8")
+                __ASM_EMIT("adds        %[count], #8")
                 __ASM_EMIT("blt         4f")
                 __ASM_EMIT("vldm        %[dst], {q0-q1}")
                 __ASM_EMIT("vldm        %[a]!, {q2-q3}")
@@ -459,11 +459,11 @@ namespace lsp
                 __ASM_EMIT("vmla.f32    q1, q5, q14")
                 __ASM_EMIT("vmla.f32    q0, q6, q15")
                 __ASM_EMIT("vmla.f32    q1, q7, q15")
-                __ASM_EMIT("sub         %[count], $8")
+                __ASM_EMIT("sub         %[count], #8")
                 __ASM_EMIT("vstm        %[dst]!, {q0-q1}")
                 /* 4x block */
                 __ASM_EMIT("4:")
-                __ASM_EMIT("adds        %[count], $4")
+                __ASM_EMIT("adds        %[count], #4")
                 __ASM_EMIT("blt         6f")
                 __ASM_EMIT("vldm        %[dst], {q0}")
                 __ASM_EMIT("vldm        %[a]!, {q2}")
@@ -472,11 +472,11 @@ namespace lsp
                 __ASM_EMIT("vmla.f32    q0, q2, q13")
                 __ASM_EMIT("vmla.f32    q0, q4, q14")
                 __ASM_EMIT("vmla.f32    q0, q6, q15")
-                __ASM_EMIT("sub         %[count], $4")
+                __ASM_EMIT("sub         %[count], #4")
                 __ASM_EMIT("vstm        %[dst]!, {q0}")
                 /* 1x blocks */
                 __ASM_EMIT("6:")
-                __ASM_EMIT("adds        %[count], $3")
+                __ASM_EMIT("adds        %[count], #3")
                 __ASM_EMIT("blt         8f")
                 __ASM_EMIT("7:")
                 __ASM_EMIT("vld1.32     {d0[], d1[]}, [%[dst]]")
@@ -486,7 +486,7 @@ namespace lsp
                 __ASM_EMIT("vmla.f32    q0, q1, q13")
                 __ASM_EMIT("vmla.f32    q0, q2, q14")
                 __ASM_EMIT("vmla.f32    q0, q3, q15")
-                __ASM_EMIT("subs        %[count], $1")
+                __ASM_EMIT("subs        %[count], #1")
                 __ASM_EMIT("vst1.32     {d0[0]}, [%[dst]]!")
                 __ASM_EMIT("bge         7b")
                 /* end */
@@ -508,7 +508,7 @@ namespace lsp
                 __ASM_EMIT("vdup.32     q13, %y[k2]")
                 __ASM_EMIT("vdup.32     q14, %y[k3]")
                 __ASM_EMIT("vdup.32     q15, %y[k4]")
-                __ASM_EMIT("subs        %[count], $16")
+                __ASM_EMIT("subs        %[count], #16")
                 __ASM_EMIT("bls         2f")
                 /* 16x blocks */
                 __ASM_EMIT("1:")
@@ -532,12 +532,12 @@ namespace lsp
                 __ASM_EMIT("vmla.f32    q1, q5, q15")
                 __ASM_EMIT("vmla.f32    q2, q6, q15")
                 __ASM_EMIT("vmla.f32    q3, q7, q15")
-                __ASM_EMIT("subs        %[count], $16")
+                __ASM_EMIT("subs        %[count], #16")
                 __ASM_EMIT("vstm        %[a]!, {q0-q3}")
                 __ASM_EMIT("bhs         1b")
                 /* 8x block */
                 __ASM_EMIT("2:")
-                __ASM_EMIT("adds        %[count], $8")
+                __ASM_EMIT("adds        %[count], #8")
                 __ASM_EMIT("blt         4f")
                 __ASM_EMIT("vldm        %[a], {q0-q1}")
                 __ASM_EMIT("vldm        %[b]!, {q2-q3}")
@@ -551,11 +551,11 @@ namespace lsp
                 __ASM_EMIT("vmla.f32    q1, q5, q14")
                 __ASM_EMIT("vmla.f32    q0, q6, q15")
                 __ASM_EMIT("vmla.f32    q1, q7, q15")
-                __ASM_EMIT("sub         %[count], $8")
+                __ASM_EMIT("sub         %[count], #8")
                 __ASM_EMIT("vstm        %[a]!, {q0-q1}")
                 /* 4x block */
                 __ASM_EMIT("4:")
-                __ASM_EMIT("adds        %[count], $4")
+                __ASM_EMIT("adds        %[count], #4")
                 __ASM_EMIT("blt         6f")
                 __ASM_EMIT("vldm        %[a], {q0}")
                 __ASM_EMIT("vldm        %[b]!, {q2}")
@@ -565,11 +565,11 @@ namespace lsp
                 __ASM_EMIT("vmla.f32    q0, q2, q13")
                 __ASM_EMIT("vmla.f32    q0, q4, q14")
                 __ASM_EMIT("vmla.f32    q0, q6, q15")
-                __ASM_EMIT("sub         %[count], $4")
+                __ASM_EMIT("sub         %[count], #4")
                 __ASM_EMIT("vstm        %[a]!, {q0}")
                 /* 1x blocks */
                 __ASM_EMIT("6:")
-                __ASM_EMIT("adds        %[count], $3")
+                __ASM_EMIT("adds        %[count], #3")
                 __ASM_EMIT("blt         8f")
                 __ASM_EMIT("7:")
                 __ASM_EMIT("vld1.32     {d0[], d1[]}, [%[a]]")
@@ -580,7 +580,7 @@ namespace lsp
                 __ASM_EMIT("vmla.f32    q0, q2, q13")
                 __ASM_EMIT("vmla.f32    q0, q4, q14")
                 __ASM_EMIT("vmla.f32    q0, q6, q15")
-                __ASM_EMIT("subs        %[count], $1")
+                __ASM_EMIT("subs        %[count], #1")
                 __ASM_EMIT("vst1.32     {d0[0]}, [%[a]]!")
                 __ASM_EMIT("bge         7b")
                 /* end */
@@ -604,7 +604,7 @@ namespace lsp
                 __ASM_EMIT("vdup.32     q13, %y[k2]")
                 __ASM_EMIT("vdup.32     q14, %y[k3]")
                 __ASM_EMIT("vdup.32     q15, %y[k4]")
-                __ASM_EMIT("subs        %[count], $16")
+                __ASM_EMIT("subs        %[count], #16")
                 __ASM_EMIT("bls         2f")
                 /* 16x blocks */
                 __ASM_EMIT("1:")
@@ -628,12 +628,12 @@ namespace lsp
                 __ASM_EMIT("vmla.f32    q1, q5, q15")
                 __ASM_EMIT("vmla.f32    q2, q6, q15")
                 __ASM_EMIT("vmla.f32    q3, q7, q15")
-                __ASM_EMIT("subs        %[count], $16")
+                __ASM_EMIT("subs        %[count], #16")
                 __ASM_EMIT("vstm        %[dst]!, {q0-q3}")
                 __ASM_EMIT("bhs         1b")
                 /* 8x block */
                 __ASM_EMIT("2:")
-                __ASM_EMIT("adds        %[count], $8")
+                __ASM_EMIT("adds        %[count], #8")
                 __ASM_EMIT("blt         4f")
                 __ASM_EMIT("vldm        %[a]!, {q0-q1}")
                 __ASM_EMIT("vldm        %[b]!, {q2-q3}")
@@ -647,11 +647,11 @@ namespace lsp
                 __ASM_EMIT("vmla.f32    q1, q5, q14")
                 __ASM_EMIT("vmla.f32    q0, q6, q15")
                 __ASM_EMIT("vmla.f32    q1, q7, q15")
-                __ASM_EMIT("sub         %[count], $8")
+                __ASM_EMIT("sub         %[count], #8")
                 __ASM_EMIT("vstm        %[dst]!, {q0-q1}")
                 /* 4x block */
                 __ASM_EMIT("4:")
-                __ASM_EMIT("adds        %[count], $4")
+                __ASM_EMIT("adds        %[count], #4")
                 __ASM_EMIT("blt         6f")
                 __ASM_EMIT("vldm        %[a]!, {q0}")
                 __ASM_EMIT("vldm        %[b]!, {q2}")
@@ -661,11 +661,11 @@ namespace lsp
                 __ASM_EMIT("vmla.f32    q0, q2, q13")
                 __ASM_EMIT("vmla.f32    q0, q4, q14")
                 __ASM_EMIT("vmla.f32    q0, q6, q15")
-                __ASM_EMIT("sub         %[count], $4")
+                __ASM_EMIT("sub         %[count], #4")
                 __ASM_EMIT("vstm        %[dst]!, {q0}")
                 /* 1x blocks */
                 __ASM_EMIT("6:")
-                __ASM_EMIT("adds        %[count], $3")
+                __ASM_EMIT("adds        %[count], #3")
                 __ASM_EMIT("blt         8f")
                 __ASM_EMIT("7:")
                 __ASM_EMIT("vld1.32     {d0[], d1[]}, [%[a]]!")
@@ -676,7 +676,7 @@ namespace lsp
                 __ASM_EMIT("vmla.f32    q0, q2, q13")
                 __ASM_EMIT("vmla.f32    q0, q4, q14")
                 __ASM_EMIT("vmla.f32    q0, q6, q15")
-                __ASM_EMIT("subs        %[count], $1")
+                __ASM_EMIT("subs        %[count], #1")
                 __ASM_EMIT("vst1.32     {d0[0]}, [%[dst]]!")
                 __ASM_EMIT("bge         7b")
                 /* end */
@@ -700,7 +700,7 @@ namespace lsp
                 __ASM_EMIT("vdup.32     q13, %y[k2]")
                 __ASM_EMIT("vdup.32     q14, %y[k3]")
                 __ASM_EMIT("vdup.32     q15, %y[k4]")
-                __ASM_EMIT("subs        %[count], $16")
+                __ASM_EMIT("subs        %[count], #16")
                 __ASM_EMIT("bls         2f")
                 /* 16x blocks */
                 __ASM_EMIT("1:")
@@ -725,12 +725,12 @@ namespace lsp
                 __ASM_EMIT("vmla.f32    q1, q9, q15")
                 __ASM_EMIT("vmla.f32    q2, q10, q15")
                 __ASM_EMIT("vmla.f32    q3, q11, q15")
-                __ASM_EMIT("subs        %[count], $16")
+                __ASM_EMIT("subs        %[count], #16")
                 __ASM_EMIT("vstm        %[dst]!, {q0-q3}")
                 __ASM_EMIT("bhs         1b")
                 /* 8x block */
                 __ASM_EMIT("2:")
-                __ASM_EMIT("adds        %[count], $8")
+                __ASM_EMIT("adds        %[count], #8")
                 __ASM_EMIT("blt         4f")
                 __ASM_EMIT("vldm        %[dst], {q0-q1}")
                 __ASM_EMIT("vldm        %[a]!, {q2-q3}")
@@ -745,11 +745,11 @@ namespace lsp
                 __ASM_EMIT("vmla.f32    q1, q7, q14")
                 __ASM_EMIT("vmla.f32    q0, q8, q15")
                 __ASM_EMIT("vmla.f32    q1, q9, q15")
-                __ASM_EMIT("sub         %[count], $8")
+                __ASM_EMIT("sub         %[count], #8")
                 __ASM_EMIT("vstm        %[dst]!, {q0-q1}")
                 /* 4x block */
                 __ASM_EMIT("4:")
-                __ASM_EMIT("adds        %[count], $4")
+                __ASM_EMIT("adds        %[count], #4")
                 __ASM_EMIT("blt         6f")
                 __ASM_EMIT("vldm        %[dst], {q0}")
                 __ASM_EMIT("vldm        %[a]!, {q2}")
@@ -760,11 +760,11 @@ namespace lsp
                 __ASM_EMIT("vmla.f32    q0, q4, q13")
                 __ASM_EMIT("vmla.f32    q0, q6, q14")
                 __ASM_EMIT("vmla.f32    q0, q8, q15")
-                __ASM_EMIT("sub         %[count], $4")
+                __ASM_EMIT("sub         %[count], #4")
                 __ASM_EMIT("vstm        %[dst]!, {q0}")
                 /* 1x blocks */
                 __ASM_EMIT("6:")
-                __ASM_EMIT("adds        %[count], $3")
+                __ASM_EMIT("adds        %[count], #3")
                 __ASM_EMIT("blt         8f")
                 __ASM_EMIT("7:")
                 __ASM_EMIT("vld1.32     {d0[], d1[]}, [%[dst]]")
@@ -776,7 +776,7 @@ namespace lsp
                 __ASM_EMIT("vmla.f32    q0, q4, q13")
                 __ASM_EMIT("vmla.f32    q0, q6, q14")
                 __ASM_EMIT("vmla.f32    q0, q8, q15")
-                __ASM_EMIT("subs        %[count], $1")
+                __ASM_EMIT("subs        %[count], #1")
                 __ASM_EMIT("vst1.32     {d0[0]}, [%[dst]]!")
                 __ASM_EMIT("bge         7b")
                 /* end */
