@@ -137,6 +137,10 @@
 
                 CEXPORT1(favx, copy);
                 CEXPORT1(favx, move);
+                CEXPORT1(favx, fill);
+                CEXPORT1(favx, fill_zero);
+                CEXPORT1(favx, fill_one);
+                CEXPORT1(favx, fill_minus_one);
 
                 CEXPORT1(favx, limit1);
                 CEXPORT1(favx, limit2);
@@ -282,6 +286,7 @@
                 CEXPORT1(favx, pcomplex_rcp1);
                 CEXPORT1(favx, pcomplex_rcp2);
 
+                CEXPORT1(favx, pcomplex_r2c);
                 CEXPORT1(favx, pcomplex_r2c_add2);
                 CEXPORT1(favx, pcomplex_r2c_sub2);
                 CEXPORT1(favx, pcomplex_r2c_rsub2);
