@@ -54,6 +54,12 @@ namespace lsp
             void sanitize1(float *dst, size_t count);
             void sanitize2(float *dst, const float *src, size_t count);
         }
+
+        namespace avx512
+        {
+            void sanitize1(float *dst, size_t count);
+            void sanitize2(float *dst, const float *src, size_t count);
+        }
     )
 
     IF_ARCH_ARM(
@@ -129,6 +135,7 @@ PTEST_BEGIN("dsp.float", sanitize, 5, 10000)
             IF_ARCH_X86(CALL(sse2::sanitize1));
             IF_ARCH_X86(CALL(avx::sanitize1));
             IF_ARCH_X86(CALL(avx2::sanitize1));
+            IF_ARCH_X86(CALL(avx512::sanitize1));
             IF_ARCH_ARM(CALL(neon_d32::sanitize1));
             IF_ARCH_AARCH64(CALL(asimd::sanitize1));
             PTEST_SEPARATOR;
@@ -137,6 +144,7 @@ PTEST_BEGIN("dsp.float", sanitize, 5, 10000)
             IF_ARCH_X86(CALL(sse2::sanitize2));
             IF_ARCH_X86(CALL(avx::sanitize2));
             IF_ARCH_X86(CALL(avx2::sanitize2));
+            IF_ARCH_X86(CALL(avx512::sanitize2));
             IF_ARCH_ARM(CALL(neon_d32::sanitize2));
             IF_ARCH_AARCH64(CALL(asimd::sanitize2));
             PTEST_SEPARATOR2;
