@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2020 Linux Studio Plugins Project <https://lsp-plug.in/>
- *           (C) 2020 Vladimir Sadovnikov <sadko4u@gmail.com>
+ * Copyright (C) 2023 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2023 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
  * This file is part of lsp-dsp-lib
  * Created on: 31 мар. 2020 г.
@@ -48,6 +48,12 @@ namespace lsp
             void    lr_to_ms(float *m, float *s, const float *l, const float *r, size_t count);
             void    ms_to_lr(float *l, float *r, const float *m, const float *s, size_t count);
         }
+
+        namespace avx512
+        {
+            void    lr_to_ms(float *m, float *s, const float *l, const float *r, size_t count);
+            void    ms_to_lr(float *l, float *r, const float *m, const float *s, size_t count);
+        }
     )
 
     IF_ARCH_ARM(
@@ -108,6 +114,7 @@ PTEST_BEGIN("dsp.msmatrix", conv2, 5, 1000)
             CALL(generic::lr_to_ms);
             IF_ARCH_X86(CALL(sse::lr_to_ms));
             IF_ARCH_X86(CALL(avx::lr_to_ms));
+            IF_ARCH_X86(CALL(avx512::lr_to_ms));
             IF_ARCH_ARM(CALL(neon_d32::lr_to_ms));
             IF_ARCH_AARCH64(CALL(asimd::lr_to_ms));
             PTEST_SEPARATOR;
@@ -115,6 +122,7 @@ PTEST_BEGIN("dsp.msmatrix", conv2, 5, 1000)
             CALL(generic::ms_to_lr);
             IF_ARCH_X86(CALL(sse::ms_to_lr));
             IF_ARCH_X86(CALL(avx::ms_to_lr));
+            IF_ARCH_X86(CALL(avx512::ms_to_lr));
             IF_ARCH_ARM(CALL(neon_d32::ms_to_lr));
             IF_ARCH_AARCH64(CALL(asimd::ms_to_lr));
             PTEST_SEPARATOR2;
