@@ -41,11 +41,21 @@ namespace lsp
             void pcomplex_div3(float *dst, const float *t, const float *b, size_t count);
         }
 
+        namespace sse3
+        {
+            void pcomplex_div3(float *dst, const float *t, const float *b, size_t count);
+        }
+
         namespace avx
         {
             void pcomplex_div3(float *dst, const float *t, const float *b, size_t count);
             void pcomplex_div3_fma3(float *dst, const float *t, const float *b, size_t count);
         }
+
+        namespace avx512
+        {
+            void pcomplex_div3(float *dst, const float *t, const float *b, size_t count);
+        }
     )
 
     IF_ARCH_ARM(
@@ -106,8 +116,10 @@ PTEST_BEGIN("dsp.pcomplex", div3, 5, 1000)
 
             CALL(generic::pcomplex_div3);
             IF_ARCH_X86(CALL(sse::pcomplex_div3));
+            IF_ARCH_X86(CALL(sse3::pcomplex_div3));
             IF_ARCH_X86(CALL(avx::pcomplex_div3));
             IF_ARCH_X86(CALL(avx::pcomplex_div3_fma3));
+            IF_ARCH_X86(CALL(avx512::pcomplex_div3));
             IF_ARCH_ARM(CALL(neon_d32::pcomplex_div3));
             IF_ARCH_AARCH64(CALL(asimd::pcomplex_div3));
             PTEST_SEPARATOR;
