@@ -50,6 +50,16 @@ namespace lsp
             void    abs_div3(float *dst, const float *src1, const float *src2, size_t count);
             void    abs_rdiv3(float *dst, const float *src1, const float *src2, size_t count);
         }
+
+        namespace avx512
+        {
+            void    abs_add3(float *dst, const float *src1, const float *src2, size_t count);
+            void    abs_sub3(float *dst, const float *src1, const float *src2, size_t count);
+            void    abs_rsub3(float *dst, const float *src1, const float *src2, size_t count);
+            void    abs_mul3(float *dst, const float *src1, const float *src2, size_t count);
+            void    abs_div3(float *dst, const float *src1, const float *src2, size_t count);
+            void    abs_rdiv3(float *dst, const float *src1, const float *src2, size_t count);
+        }
     )
 
     IF_ARCH_X86_64(
@@ -130,6 +140,7 @@ PTEST_BEGIN("dsp.pmath", abs_op3, 5, 1000)
             CALL(generic::abs_add3);
             IF_ARCH_X86(CALL(sse::abs_add3));
             IF_ARCH_X86_64(CALL(avx::x64_abs_add3));
+            IF_ARCH_X86(CALL(avx512::abs_add3));
             IF_ARCH_ARM(CALL(neon_d32::abs_add3));
             IF_ARCH_AARCH64(CALL(asimd::abs_add3));
             PTEST_SEPARATOR;
@@ -137,6 +148,7 @@ PTEST_BEGIN("dsp.pmath", abs_op3, 5, 1000)
             CALL(generic::abs_sub3);
             IF_ARCH_X86(CALL(sse::abs_sub3));
             IF_ARCH_X86_64(CALL(avx::x64_abs_sub3));
+            IF_ARCH_X86(CALL(avx512::abs_sub3));
             IF_ARCH_ARM(CALL(neon_d32::abs_sub3));
             IF_ARCH_AARCH64(CALL(asimd::abs_sub3));
             PTEST_SEPARATOR;
@@ -144,6 +156,7 @@ PTEST_BEGIN("dsp.pmath", abs_op3, 5, 1000)
             CALL(generic::abs_rsub3);
             IF_ARCH_X86(CALL(sse::abs_rsub3));
             IF_ARCH_X86_64(CALL(avx::x64_abs_rsub3));
+            IF_ARCH_X86(CALL(avx512::abs_rsub3));
             IF_ARCH_ARM(CALL(neon_d32::abs_rsub3));
             IF_ARCH_AARCH64(CALL(asimd::abs_rsub3));
             PTEST_SEPARATOR;
@@ -151,6 +164,7 @@ PTEST_BEGIN("dsp.pmath", abs_op3, 5, 1000)
             CALL(generic::abs_mul3);
             IF_ARCH_X86(CALL(sse::abs_mul3));
             IF_ARCH_X86_64(CALL(avx::x64_abs_mul3));
+            IF_ARCH_X86(CALL(avx512::abs_mul3));
             IF_ARCH_ARM(CALL(neon_d32::abs_mul3));
             IF_ARCH_AARCH64(CALL(asimd::abs_mul3));
             PTEST_SEPARATOR;
@@ -158,6 +172,7 @@ PTEST_BEGIN("dsp.pmath", abs_op3, 5, 1000)
             CALL(generic::abs_div3);
             IF_ARCH_X86(CALL(sse::abs_div3));
             IF_ARCH_X86_64(CALL(avx::x64_abs_div3));
+            IF_ARCH_X86(CALL(avx512::abs_div3));
             IF_ARCH_ARM(CALL(neon_d32::abs_div3));
             IF_ARCH_AARCH64(CALL(asimd::abs_div3));
             PTEST_SEPARATOR;
@@ -165,6 +180,7 @@ PTEST_BEGIN("dsp.pmath", abs_op3, 5, 1000)
             CALL(generic::abs_rdiv3);
             IF_ARCH_X86(CALL(sse::abs_rdiv3));
             IF_ARCH_X86_64(CALL(avx::x64_abs_rdiv3));
+            IF_ARCH_X86(CALL(avx512::abs_rdiv3));
             IF_ARCH_ARM(CALL(neon_d32::abs_rdiv3));
             IF_ARCH_AARCH64(CALL(asimd::abs_rdiv3));
             PTEST_SEPARATOR2;
