@@ -94,6 +94,18 @@ namespace lsp
             void    fmmod_k4_fma3(float *dst, const float *src1, const float *src2, float k, size_t count);
             void    fmrmod_k4_fma3(float *dst, const float *src1, const float *src2, float k, size_t count);
         }
+
+        namespace avx512
+        {
+            void    fmadd_k4(float *dst, const float *src1, const float *src2, float k, size_t count);
+            void    fmsub_k4(float *dst, const float *src1, const float *src2, float k, size_t count);
+            void    fmrsub_k4(float *dst, const float *src1, const float *src2, float k, size_t count);
+            void    fmmul_k4(float *dst, const float *src1, const float *src2, float k, size_t count);
+            void    fmdiv_k4(float *dst, const float *src1, const float *src2, float k, size_t count);
+            void    fmrdiv_k4(float *dst, const float *src1, const float *src2, float k, size_t count);
+            void    fmmod_k4(float *dst, const float *src1, const float *src2, float k, size_t count);
+            void    fmrmod_k4(float *dst, const float *src1, const float *src2, float k, size_t count);
+        }
     )
 
     IF_ARCH_ARM(
@@ -170,6 +182,7 @@ PTEST_BEGIN("dsp.pmath", fmop_k4, 5, 1000)
             IF_ARCH_X86(CALL(avx::fmadd_k4_fma3));
             IF_ARCH_X86(CALL(avx2::fmadd_k4));
             IF_ARCH_X86(CALL(avx2::fmadd_k4_fma3));
+            IF_ARCH_X86(CALL(avx512::fmadd_k4));
             IF_ARCH_ARM(CALL(neon_d32::fmadd_k4));
             IF_ARCH_AARCH64(CALL(asimd::fmadd_k4));
             PTEST_SEPARATOR;
@@ -180,6 +193,7 @@ PTEST_BEGIN("dsp.pmath", fmop_k4, 5, 1000)
             IF_ARCH_X86(CALL(avx::fmsub_k4_fma3));
             IF_ARCH_X86(CALL(avx2::fmsub_k4));
             IF_ARCH_X86(CALL(avx2::fmsub_k4_fma3));
+            IF_ARCH_X86(CALL(avx512::fmsub_k4));
             IF_ARCH_ARM(CALL(neon_d32::fmsub_k4));
             IF_ARCH_AARCH64(CALL(asimd::fmsub_k4));
             PTEST_SEPARATOR;
@@ -190,6 +204,7 @@ PTEST_BEGIN("dsp.pmath", fmop_k4, 5, 1000)
             IF_ARCH_X86(CALL(avx::fmrsub_k4_fma3));
             IF_ARCH_X86(CALL(avx2::fmrsub_k4));
             IF_ARCH_X86(CALL(avx2::fmrsub_k4_fma3));
+            IF_ARCH_X86(CALL(avx512::fmrsub_k4));
             IF_ARCH_ARM(CALL(neon_d32::fmrsub_k4));
             IF_ARCH_AARCH64(CALL(asimd::fmrsub_k4));
             PTEST_SEPARATOR;
@@ -198,6 +213,7 @@ PTEST_BEGIN("dsp.pmath", fmop_k4, 5, 1000)
             IF_ARCH_X86(CALL(sse::fmmul_k4));
             IF_ARCH_X86(CALL(avx::fmmul_k4));
             IF_ARCH_X86(CALL(avx2::fmmul_k4));
+            IF_ARCH_X86(CALL(avx512::fmmul_k4));
             IF_ARCH_ARM(CALL(neon_d32::fmmul_k4));
             IF_ARCH_AARCH64(CALL(asimd::fmmul_k4));
             PTEST_SEPARATOR;
@@ -206,6 +222,7 @@ PTEST_BEGIN("dsp.pmath", fmop_k4, 5, 1000)
             IF_ARCH_X86(CALL(sse::fmdiv_k4));
             IF_ARCH_X86(CALL(avx::fmdiv_k4));
             IF_ARCH_X86(CALL(avx2::fmdiv_k4));
+            IF_ARCH_X86(CALL(avx512::fmdiv_k4));
             IF_ARCH_ARM(CALL(neon_d32::fmdiv_k4));
             IF_ARCH_AARCH64(CALL(asimd::fmdiv_k4));
             PTEST_SEPARATOR;
@@ -214,6 +231,7 @@ PTEST_BEGIN("dsp.pmath", fmop_k4, 5, 1000)
             IF_ARCH_X86(CALL(sse::fmrdiv_k4));
             IF_ARCH_X86(CALL(avx::fmrdiv_k4));
             IF_ARCH_X86(CALL(avx2::fmrdiv_k4));
+            IF_ARCH_X86(CALL(avx512::fmrdiv_k4));
             IF_ARCH_ARM(CALL(neon_d32::fmrdiv_k4));
             IF_ARCH_AARCH64(CALL(asimd::fmrdiv_k4));
             PTEST_SEPARATOR;
@@ -224,6 +242,7 @@ PTEST_BEGIN("dsp.pmath", fmop_k4, 5, 1000)
             IF_ARCH_X86(CALL(avx::fmmod_k4_fma3));
             IF_ARCH_X86(CALL(avx2::fmmod_k4));
             IF_ARCH_X86(CALL(avx2::fmmod_k4_fma3));
+            IF_ARCH_X86(CALL(avx512::fmmod_k4));
             IF_ARCH_ARM(CALL(neon_d32::fmmod_k4));
             IF_ARCH_AARCH64(CALL(asimd::fmmod_k4));
             PTEST_SEPARATOR;
@@ -234,6 +253,7 @@ PTEST_BEGIN("dsp.pmath", fmop_k4, 5, 1000)
             IF_ARCH_X86(CALL(avx::fmrmod_k4_fma3));
             IF_ARCH_X86(CALL(avx2::fmrmod_k4));
             IF_ARCH_X86(CALL(avx2::fmrmod_k4_fma3));
+            IF_ARCH_X86(CALL(avx512::fmrmod_k4));
             IF_ARCH_ARM(CALL(neon_d32::fmrmod_k4));
             IF_ARCH_AARCH64(CALL(asimd::fmrmod_k4));
             PTEST_SEPARATOR2;
