@@ -60,6 +60,16 @@ namespace lsp
             void pamin2(float *dst, const float *src, size_t count);
             void pamax2(float *dst, const float *src, size_t count);
         }
+
+        namespace avx512
+        {
+            void pmin2(float *dst, const float *src, size_t count);
+            void pmax2(float *dst, const float *src, size_t count);
+            void psmin2(float *dst, const float *src, size_t count);
+            void psmax2(float *dst, const float *src, size_t count);
+            void pamin2(float *dst, const float *src, size_t count);
+            void pamax2(float *dst, const float *src, size_t count);
+        }
     )
 
     IF_ARCH_ARM(
@@ -90,7 +100,7 @@ namespace lsp
 typedef void (* min2_t)(float *dst, const float *src, size_t count);
 
 //-----------------------------------------------------------------------------
-PTEST_BEGIN("dsp.pmath", minmax2, 5, 10000)
+PTEST_BEGIN("dsp.pmath", minmax2, 5, 2000)
 
     void call(const char *label, float *dst, const float *src, size_t count, min2_t func)
     {
@@ -128,6 +138,7 @@ PTEST_BEGIN("dsp.pmath", minmax2, 5, 10000)
             CALL(generic::pmin2);
             IF_ARCH_X86(CALL(sse::pmin2));
             IF_ARCH_X86(CALL(avx::pmin2));
+            IF_ARCH_X86(CALL(avx512::pmin2));
             IF_ARCH_ARM(CALL(neon_d32::pmin2));
             IF_ARCH_AARCH64(CALL(asimd::pmin2));
             PTEST_SEPARATOR;
@@ -135,6 +146,7 @@ PTEST_BEGIN("dsp.pmath", minmax2, 5, 10000)
             CALL(generic::pmax2);
             IF_ARCH_X86(CALL(sse::pmax2));
             IF_ARCH_X86(CALL(avx::pmax2));
+            IF_ARCH_X86(CALL(avx512::pmax2));
             IF_ARCH_ARM(CALL(neon_d32::pmax2));
             IF_ARCH_AARCH64(CALL(asimd::pmax2));
             PTEST_SEPARATOR;
@@ -142,6 +154,7 @@ PTEST_BEGIN("dsp.pmath", minmax2, 5, 10000)
             CALL(generic::psmin2);
             IF_ARCH_X86(CALL(sse::psmin2));
             IF_ARCH_X86(CALL(avx::psmin2));
+            IF_ARCH_X86(CALL(avx512::psmin2));
             IF_ARCH_ARM(CALL(neon_d32::psmin2));
             IF_ARCH_AARCH64(CALL(asimd::psmin2));
             PTEST_SEPARATOR;
@@ -149,6 +162,7 @@ PTEST_BEGIN("dsp.pmath", minmax2, 5, 10000)
             CALL(generic::psmax2);
             IF_ARCH_X86(CALL(sse::psmax2));
             IF_ARCH_X86(CALL(avx::psmax2));
+            IF_ARCH_X86(CALL(avx512::psmax2));
             IF_ARCH_ARM(CALL(neon_d32::psmax2));
             IF_ARCH_AARCH64(CALL(asimd::psmax2));
             PTEST_SEPARATOR;
@@ -156,6 +170,7 @@ PTEST_BEGIN("dsp.pmath", minmax2, 5, 10000)
             CALL(generic::pamin2);
             IF_ARCH_X86(CALL(sse::pamin2));
             IF_ARCH_X86(CALL(avx::pamin2));
+            IF_ARCH_X86(CALL(avx512::pamin2));
             IF_ARCH_ARM(CALL(neon_d32::pamin2));
             IF_ARCH_AARCH64(CALL(asimd::pamin2));
             PTEST_SEPARATOR;
@@ -163,6 +178,7 @@ PTEST_BEGIN("dsp.pmath", minmax2, 5, 10000)
             CALL(generic::pamax2);
             IF_ARCH_X86(CALL(sse::pamax2));
             IF_ARCH_X86(CALL(avx::pamax2));
+            IF_ARCH_X86(CALL(avx512::pamax2));
             IF_ARCH_ARM(CALL(neon_d32::pamax2));
             IF_ARCH_AARCH64(CALL(asimd::pamax2));
             PTEST_SEPARATOR2;
