@@ -86,6 +86,18 @@ namespace lsp
             void    mod_k3_fma3(float *dst, const float *src, float k, size_t count);
             void    rmod_k3_fma3(float *dst, const float *src, float k, size_t count);
         }
+
+        namespace avx512
+        {
+            void    add_k3(float *dst, const float *src, float k, size_t count);
+            void    sub_k3(float *dst, const float *src, float k, size_t count);
+            void    rsub_k3(float *dst, const float *src, float k, size_t count);
+            void    mul_k3(float *dst, const float *src, float k, size_t count);
+            void    div_k3(float *dst, const float *src, float k, size_t count);
+            void    rdiv_k3(float *dst, const float *src, float k, size_t count);
+            void    mod_k3(float *dst, const float *src, float k, size_t count);
+            void    rmod_k3(float *dst, const float *src, float k, size_t count);
+        }
     )
 
     IF_ARCH_ARM(
@@ -160,6 +172,7 @@ PTEST_BEGIN("dsp.pmath", op_k3, 5, 1000)
             IF_ARCH_X86(CALL(sse::add_k3));
             IF_ARCH_X86(CALL(avx::add_k3));
             IF_ARCH_X86(CALL(avx2::add_k3));
+            IF_ARCH_X86(CALL(avx512::add_k3));
             IF_ARCH_ARM(CALL(neon_d32::add_k3));
             IF_ARCH_AARCH64(CALL(asimd::add_k3));
             PTEST_SEPARATOR;
@@ -168,6 +181,7 @@ PTEST_BEGIN("dsp.pmath", op_k3, 5, 1000)
             IF_ARCH_X86(CALL(sse::sub_k3));
             IF_ARCH_X86(CALL(avx::sub_k3));
             IF_ARCH_X86(CALL(avx2::sub_k3));
+            IF_ARCH_X86(CALL(avx512::sub_k3));
             IF_ARCH_ARM(CALL(neon_d32::sub_k3));
             IF_ARCH_AARCH64(CALL(asimd::sub_k3));
             PTEST_SEPARATOR;
@@ -176,6 +190,7 @@ PTEST_BEGIN("dsp.pmath", op_k3, 5, 1000)
             IF_ARCH_X86(CALL(sse::rsub_k3));
             IF_ARCH_X86(CALL(avx::rsub_k3));
             IF_ARCH_X86(CALL(avx2::rsub_k3));
+            IF_ARCH_X86(CALL(avx512::rsub_k3));
             IF_ARCH_ARM(CALL(neon_d32::rsub_k3));
             IF_ARCH_AARCH64(CALL(asimd::rsub_k3));
             PTEST_SEPARATOR;
@@ -184,6 +199,7 @@ PTEST_BEGIN("dsp.pmath", op_k3, 5, 1000)
             IF_ARCH_X86(CALL(sse::mul_k3));
             IF_ARCH_X86(CALL(avx::mul_k3));
             IF_ARCH_X86(CALL(avx2::mul_k3));
+            IF_ARCH_X86(CALL(avx512::mul_k3));
             IF_ARCH_ARM(CALL(neon_d32::mul_k3));
             IF_ARCH_AARCH64(CALL(asimd::mul_k3));
             PTEST_SEPARATOR;
@@ -192,6 +208,7 @@ PTEST_BEGIN("dsp.pmath", op_k3, 5, 1000)
             IF_ARCH_X86(CALL(sse::div_k3));
             IF_ARCH_X86(CALL(avx::div_k3));
             IF_ARCH_X86(CALL(avx2::div_k3));
+            IF_ARCH_X86(CALL(avx512::div_k3));
             IF_ARCH_ARM(CALL(neon_d32::div_k3));
             IF_ARCH_AARCH64(CALL(asimd::div_k3));
             PTEST_SEPARATOR;
@@ -200,6 +217,7 @@ PTEST_BEGIN("dsp.pmath", op_k3, 5, 1000)
             IF_ARCH_X86(CALL(sse::rdiv_k3));
             IF_ARCH_X86(CALL(avx::rdiv_k3));
             IF_ARCH_X86(CALL(avx2::rdiv_k3));
+            IF_ARCH_X86(CALL(avx512::rdiv_k3));
             IF_ARCH_ARM(CALL(neon_d32::rdiv_k3));
             IF_ARCH_AARCH64(CALL(asimd::rdiv_k3));
             PTEST_SEPARATOR;
@@ -210,6 +228,7 @@ PTEST_BEGIN("dsp.pmath", op_k3, 5, 1000)
             IF_ARCH_X86(CALL(avx::mod_k3_fma3));
             IF_ARCH_X86(CALL(avx2::mod_k3));
             IF_ARCH_X86(CALL(avx2::mod_k3_fma3));
+            IF_ARCH_X86(CALL(avx512::mod_k3));
             IF_ARCH_ARM(CALL(neon_d32::mod_k3));
             IF_ARCH_AARCH64(CALL(asimd::mod_k3));
             PTEST_SEPARATOR;
@@ -220,6 +239,7 @@ PTEST_BEGIN("dsp.pmath", op_k3, 5, 1000)
             IF_ARCH_X86(CALL(avx::rmod_k3_fma3));
             IF_ARCH_X86(CALL(avx2::rmod_k3));
             IF_ARCH_X86(CALL(avx2::rmod_k3_fma3));
+            IF_ARCH_X86(CALL(avx512::rmod_k3));
             IF_ARCH_ARM(CALL(neon_d32::rmod_k3));
             IF_ARCH_AARCH64(CALL(asimd::rmod_k3));
             PTEST_SEPARATOR2;
