@@ -42,10 +42,6 @@ namespace lsp
          */
         class LSP_DSP_UNITS_PUBLIC Sample
         {
-            private:
-                Sample & operator = (const Sample &);
-                Sample(const Sample &);
-
             private:
                 float              *vBuffer;        // Sample data
                 size_t              nSampleRate;    // Sample rate
@@ -76,8 +72,13 @@ namespace lsp
 
             public:
                 explicit Sample();
+                Sample(const Sample &) = delete;
+                Sample(Sample &&) = delete;
                 ~Sample();
 
+                Sample & operator = (const Sample &) = delete;
+                Sample & operator = (Sample &&) = delete;
+
                 /**
                  * Create uninitialied sample
                  */
@@ -219,7 +220,15 @@ namespace lsp
                  * @param length initial sample length
                  * @return true if data was successful allocated
                  */
-                bool init(size_t channels, size_t max_length, size_t length = 0);
+                bool init(size_t channels, size_t max_length, size_t length);
+
+                /** Initialize sample, all previously allocated data will be lost
+                 *
+                 * @param channels number of channels
+                 * @param length initial sample length
+                 * @return true if data was successful allocated
+                 */
+                bool init(size_t channels, size_t length);
 
                 /** Resize sample, all previously allocated data will be kept
                  *
@@ -311,6 +320,22 @@ namespace lsp
                  */
                 void normalize(float gain, sample_normalize_t mode);
 
+                /**
+                 * apply gain to the whole sample
+                 * @param gain gain to apply
+                 * @return status of operation
+                 */
+                status_t apply_gain(float gain);
+
+                /**
+                 * Apply gain to the selected range of the sample
+                 * @param gain gain to apply
+                 * @param first the index of the first sample to modify
+                 * @param count the number of samples to modify
+                 * @return status of operation
+                 */
+                status_t apply_gain(float gain, size_t first, size_t count);
+
                 /**
                  * Swap contents with another sample
                  * @param dst sample to perform swap
