@@ -91,10 +91,6 @@ namespace lsp
          */
         class LSP_DSP_UNITS_PUBLIC Crossover
         {
-            private:
-                Crossover & operator = (const Crossover &);
-                Crossover(const Crossover &);
-
             protected:
                 enum xover_type_t
                 {
@@ -103,6 +99,14 @@ namespace lsp
                     FILTER_APF                          // All-pass filter
                 };
 
+                enum reconfigure_t
+                {
+                    R_GAIN          = 1 << 0,           // We can reconfigure band gain in softer mode
+                    R_SPLIT         = 1 << 1,           // Need to reconfigure filter order
+
+                    R_ALL           = R_GAIN | R_SPLIT
+                };
+
                 typedef struct split_t
                 {
                     Equalizer           sLPF;           // Lo-pass filter
@@ -129,14 +133,6 @@ namespace lsp
                     size_t              nId;            // Number of the band
                 } band_t;
 
-                enum reconfigure_t
-                {
-                    R_GAIN          = 1 << 0,           // We can reconfigure band gain in softer mode
-                    R_SPLIT         = 1 << 1,           // Need to reconfigure filter order
-
-                    R_ALL           = R_GAIN | R_SPLIT
-                } reconfigure_t;
-
             protected:
                 size_t          nReconfigure;   // Change flag
                 size_t          nSplits;        // Number of splits
@@ -157,8 +153,13 @@ namespace lsp
 
             public:
                 explicit Crossover();
+                Crossover(const Crossover &) = delete;
+                Crossover(Crossover &) = delete;
                 ~Crossover();
 
+                Crossover & operator = (const Crossover &) = delete;
+                Crossover & operator = (Crossover &&) = delete;
+
                 /** Construct crossover
                  *
                  */
