@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2022 Linux Studio Plugins Project <https://lsp-plug.in/>
- *           (C) 2022 Vladimir Sadovnikov <sadko4u@gmail.com>
+ * Copyright (C) 2023 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2023 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
  * This file is part of lsp-plugin-fw
  * Created on: 24 дек. 2022 г.
@@ -110,7 +110,11 @@ namespace lsp
 
             // Cleanup generated metadata
             for (size_t i=0, n=vGenMetadata.size(); i<n; ++i)
-                meta::drop_port_metadata(vGenMetadata.uget(i));
+            {
+                meta::port_t *p = vGenMetadata.uget(i);
+                lsp_trace("destroy generated port metadata %p", p);
+                meta::drop_port_metadata(p);
+            }
             vGenMetadata.flush();
 
             // Destroy the loader
@@ -359,7 +363,7 @@ namespace lsp
 
         status_t Wrapper::generate_audio_port_groups(const meta::plugin_t *meta)
         {
-            // Generate mofifiable lists of input and output ports
+            // Generate modifiable lists of input and output ports
             lltl::parray<plug::IPort> ins, outs;
             for (size_t i=0, n=vAllPorts.size(); i < n; ++i)
             {
@@ -375,14 +379,12 @@ namespace lsp
             }
 
             // Try to create ports using port groups
-            audio_group_t *in_main = NULL, *out_main = NULL;
-            for (const meta::port_group_t *pg = (meta != NULL) ? meta->port_groups : NULL;
-                (pg != NULL) && (pg->id != NULL);
-                ++pg)
+            audio_group_t *in_main = NULL, *out_main = NULL, *grp = NULL;
+            const meta::port_group_t *port_groups = (meta != NULL) ? meta->port_groups : NULL;
+            for (const meta::port_group_t *pg = port_groups; (pg != NULL) && (pg->id != NULL); ++pg)
             {
                 // Create group and add to list
-                audio_group_t *grp  = create_audio_group(pg, &ins, &outs);
-                if (grp == NULL)
+                if ((grp  = create_audio_group(pg, &ins, &outs)) == NULL)
                     return STATUS_NO_MEM;
 
                 // Add the group to list or keep as a separate pointer because CLAP
@@ -427,6 +429,56 @@ namespace lsp
                 }
             }
 
+            // We need to create main audio groups anyway
+            if ((ins.size() > 0) && (!in_main))
+            {
+                if ((grp = alloc_audio_group(ins.size())) == NULL)
+                    return STATUS_NO_MEM;
+
+                // Initialize the audio group
+                grp->nType          = meta::GRP_MONO;
+                grp->nFlags         = CLAP_AUDIO_PORT_REQUIRES_COMMON_SAMPLE_SIZE | CLAP_AUDIO_PORT_IS_MAIN;
+                grp->nInPlace       = -1;
+                grp->sName          = "main_in";
+                grp->nPorts         = ins.size();
+                for (size_t i=0, n=ins.size(); i<n; ++i)
+                    grp->vPorts[i]      = static_cast<clap::AudioPort *>(ins.uget(i));
+
+                if (!vAudioIn.add(grp))
+                {
+                    destroy_audio_group(grp);
+                    return STATUS_NO_MEM;
+                }
+                in_main             = grp;
+
+                lsp_trace("Created default main input group id=%s for %d ports", grp->sName, grp->nPorts);
+            }
+
+            if ((outs.size() > 0) && (!out_main))
+            {
+                audio_group_t *grp  = alloc_audio_group(outs.size());
+                if (grp == NULL)
+                    return STATUS_NO_MEM;
+
+                // Initialize the audio group
+                grp->nType          = meta::GRP_MONO;
+                grp->nFlags         = CLAP_AUDIO_PORT_REQUIRES_COMMON_SAMPLE_SIZE | CLAP_AUDIO_PORT_IS_MAIN;
+                grp->nInPlace       = -1;
+                grp->sName          = "main_out";
+                grp->nPorts         = outs.size();
+                for (size_t i=0, n=outs.size(); i<n; ++i)
+                    grp->vPorts[i]      = static_cast<clap::AudioPort *>(outs.uget(i));
+
+                if (!vAudioIn.add(grp))
+                {
+                    destroy_audio_group(grp);
+                    return STATUS_NO_MEM;
+                }
+                out_main            = grp;
+
+                lsp_trace("Created default main output group id=%s for %d ports", grp->sName, grp->nPorts);
+            }
+
             // Do some optimizations for the host
             if ((in_main != NULL) && (out_main != NULL) && (in_main->nPorts == out_main->nPorts))
             {
@@ -434,24 +486,32 @@ namespace lsp
                 out_main->nInPlace  = vAudioIn.index_of(in_main);
             }
 
-            // Create the rest input ports
+            // Create the rest input ports if they do not belong to any audio group
             for (size_t i=0, n=ins.size(); i<n; ++i)
             {
                 plug::IPort *p      = ins.uget(i);
                 audio_group_t *grp  = create_audio_group(p);
                 if (grp == NULL)
                     return STATUS_NO_MEM;
-                vAudioIn.add(grp);
+                if (!vAudioIn.add(grp))
+                {
+                    destroy_audio_group(grp);
+                    return STATUS_NO_MEM;
+                }
             }
 
-            // Create the rest output ports
+            // Create the rest output ports if they do not belong to any audio group
             for (size_t i=0, n=outs.size(); i<n; ++i)
             {
                 plug::IPort *p      = outs.uget(i);
                 audio_group_t *grp  = create_audio_group(p);
                 if (grp == NULL)
                     return STATUS_NO_MEM;
-                vAudioOut.add(grp);
+                if (!vAudioOut.add(grp))
+                {
+                    destroy_audio_group(grp);
+                    return STATUS_NO_MEM;
+                }
             }
 
             return STATUS_OK;
@@ -694,8 +754,8 @@ namespace lsp
                         if ((pp != NULL) && (pp->clap_set_value(ev->value)))
                         {
                             lsp_trace("port changed (set): %s, offset=%d", pp->metadata()->id, int(offset));
-                            if (pExt->state != NULL)
-                                pExt->state->mark_dirty(pHost);
+//                            if (pExt->state != NULL)
+//                                pExt->state->mark_dirty(pHost);
                             bUpdateSettings     = true;
                         }
                         break;
@@ -710,8 +770,8 @@ namespace lsp
                         if ((pp != NULL) && (pp->clap_mod_value(ev->amount)))
                         {
                             lsp_trace("port changed (mod): %s, offset=%d", pp->metadata()->id, int(offset));
-                            if (pExt->state != NULL)
-                                pExt->state->mark_dirty(pHost);
+//                            if (pExt->state != NULL)
+//                                pExt->state->mark_dirty(pHost);
                             bUpdateSettings     = true;
                         }
                         break;
@@ -1513,7 +1573,7 @@ namespace lsp
             if (magic != clap::LSP_CLAP_MAGIC)
             {
                 lsp_warn("Invalid state header signature");
-                return res;
+                return STATUS_NO_DATA;
             }
             // Read version
             if ((res = read_fully(is, &version)) != STATUS_OK)
@@ -1525,7 +1585,7 @@ namespace lsp
             if (version != clap::LSP_CLAP_VERSION)
             {
                 lsp_warn("Unsupported version %d", int(version));
-                return res;
+                return STATUS_NO_DATA;
             }
 
             // Lock the KVT
@@ -1667,7 +1727,7 @@ namespace lsp
             info->max_value     = max;
             info->default_value = dfl;
 
-            lsp_trace("id=%s, min=%f, max=%f, dfl=%f", meta->id, min, max, dfl);
+            lsp_trace("id=%s, min=%f (0), max=%f (1), dfl=%f (%f)", meta->id, min, max, meta->start, dfl);
 
             return STATUS_OK;
         }
@@ -1730,18 +1790,28 @@ namespace lsp
             // Get the parameter port
             plug::IPort *p = find_param(param_id);
             if (p == NULL)
+            {
+                lsp_warn("parameter %d not found", int(param_id));
                 return STATUS_NOT_FOUND;
+            }
             const meta::port_t *meta = p->metadata();
             if (meta == NULL)
+            {
+                lsp_warn("metadata for port %p is not present", p);
                 return STATUS_BAD_STATE;
+            }
 
             float parsed = 0.0f;
             status_t res = meta::parse_value(&parsed, text, meta, true);
             if (res != STATUS_OK)
+            {
+                lsp_warn("parse_value for port id=\"%s\" name=\"%s\", text=\"%s\" failed with code %d",
+                    meta->id, meta->name, text, int(res));
                 return res;
+            }
 
             parsed      = meta::limit_value(meta, parsed);
-            lsp_trace("parsed = %f", parsed);
+            lsp_trace("port id=\"%s\" parsed = %f", meta->id, parsed);
 
             if (value != NULL)
             {
@@ -1777,8 +1847,8 @@ namespace lsp
                         if ((pp != NULL) && (pp->clap_set_value(ev->value)))
                         {
                             lsp_trace("port changed (set): %s, offset=%d", pp->metadata()->id, int(hdr->time));
-                            if (pExt->state != NULL)
-                                pExt->state->mark_dirty(pHost);
+//                            if (pExt->state != NULL)
+//                                pExt->state->mark_dirty(pHost);
                             bUpdateSettings     = true;
                         }
                         break;
@@ -1793,8 +1863,8 @@ namespace lsp
                         if ((pp != NULL) && (pp->clap_mod_value(ev->amount)))
                         {
                             lsp_trace("port changed (mod): %s, offset=%d", pp->metadata()->id, int(hdr->time));
-                            if (pExt->state != NULL)
-                                pExt->state->mark_dirty(pHost);
+//                            if (pExt->state != NULL)
+//                                pExt->state->mark_dirty(pHost);
                             bUpdateSettings     = true;
                         }
                         break;
