@@ -29,6 +29,7 @@
 #include <lsp-plug.in/common/atomic.h>
 #include <lsp-plug.in/common/endian.h>
 #include <lsp-plug.in/dsp/dsp.h>
+#include <lsp-plug.in/plug-fw/core/osc_buffer.h>
 #include <lsp-plug.in/plug-fw/meta/func.h>
 #include <lsp-plug.in/plug-fw/plug.h>
 #include <lsp-plug.in/plug-fw/wrap/clap/data.h>
@@ -628,7 +629,7 @@ namespace lsp
         class OscPort: public Port
         {
             private:
-                plug::osc_buffer_t     *pFB;
+                core::osc_buffer_t     *pFB;
 
             public:
                 explicit OscPort(const meta::port_t *meta):
@@ -649,7 +650,7 @@ namespace lsp
 
                 virtual int init()
                 {
-                    pFB     = plug::osc_buffer_t::create(OSC_BUFFER_MAX);
+                    pFB     = core::osc_buffer_t::create(OSC_BUFFER_MAX);
                     return (pFB == NULL) ? STATUS_NO_MEM : STATUS_OK;
                 }
 
@@ -657,7 +658,7 @@ namespace lsp
                 {
                     if (pFB != NULL)
                     {
-                        plug::osc_buffer_t::destroy(pFB);
+                        core::osc_buffer_t::destroy(pFB);
                         pFB     = NULL;
                     }
                 }
