@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2021 Linux Studio Plugins Project <https://lsp-plug.in/>
- *           (C) 2021 Vladimir Sadovnikov <sadko4u@gmail.com>
+ * Copyright (C) 2023 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2023 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
  * This file is part of lsp-plugin-fw
  * Created on: 18 мая 2021 г.
@@ -90,6 +90,8 @@ namespace lsp
                 sSmooth.init(pWrapper, gm->smooth());
                 sFill.init(pWrapper, gm->fill());
                 sStrobes.init(pWrapper, gm->strobes());
+                sXAxis.init(pWrapper, gm->haxis());
+                sYAxis.init(pWrapper, gm->vaxis());
 
                 sColor.init(pWrapper, gm->color());
                 sFillColor.init(pWrapper, gm->fill_color());
@@ -115,21 +117,25 @@ namespace lsp
                 set_param(gm->origin(), "center", name, value);
                 set_param(gm->origin(), "o", name, value);
 
-                set_param(gm->haxis(), "haxis", name, value);
-                set_param(gm->haxis(), "xaxis", name, value);
-                set_param(gm->haxis(), "basis", name, value);
-                set_param(gm->haxis(), "ox", name, value);
-
-                set_param(gm->vaxis(), "vaxis", name, value);
-                set_param(gm->vaxis(), "yaxis", name, value);
-                set_param(gm->vaxis(), "parallel", name, value);
-                set_param(gm->vaxis(), "oy", name, value);
+                set_param(gm->priority(), "priority", name, value);
+                set_param(gm->priority_group(), "priority_group", name, value);
+                set_param(gm->priority_group(), "pgroup", name, value);
 
                 sWidth.set("width", name, value);
                 sSmooth.set("smooth", name, value);
                 sFill.set("fill", name, value);
                 sStrobes.set("strobes", name, value);
 
+                sXAxis.set("haxis", name, value);
+                sXAxis.set("xaxis", name, value);
+                sXAxis.set("basis", name, value);
+                sXAxis.set("ox", name, value);
+
+                sYAxis.set("vaxis", name, value);
+                sYAxis.set("yaxis", name, value);
+                sYAxis.set("parallel", name, value);
+                sYAxis.set("oy", name, value);
+
                 sColor.set("color", name, value);
                 sFillColor.set("fill.color", name, value);
                 sFillColor.set("fcolor", name, value);
