@@ -21,7 +21,6 @@
 
 #include <lsp-plug.in/plug-fw/const.h>
 #include <lsp-plug.in/plug-fw/plug/data.h>
-#include <lsp-plug.in/common/endian.h>
 #include <lsp-plug.in/common/alloc.h>
 #include <lsp-plug.in/common/atomic.h>
 #include <lsp-plug.in/stdlib/string.h>
@@ -114,6 +113,7 @@ namespace lsp
                 f->id                   = 0;
                 f->head                 = 0;
                 f->tail                 = 0;
+                f->size                 = 0;
                 f->length               = 0;
             }
 
@@ -139,6 +139,7 @@ namespace lsp
                 f->id                   = 0;
                 f->head                 = 0;
                 f->tail                 = 0;
+                f->size                 = 0;
                 f->length               = 0;
             }
 
@@ -177,12 +178,10 @@ namespace lsp
             return (f->id == frame) ? head : -STATUS_NOT_FOUND;
         }
 
-        ssize_t stream_t::get_size(uint32_t frame) const
+        ssize_t stream_t::get_frame_size(uint32_t frame) const
         {
             const frame_t *f = &vFrames[frame & (nFrameCap - 1)];
-            ssize_t size = f->tail - f->head;
-            if (size < 0)
-                size       += nBufCap;
+            ssize_t size = f->size;
             return (f->id == frame) ? size : -STATUS_NOT_FOUND;
         }
 
@@ -214,6 +213,7 @@ namespace lsp
             next->id        = frame_id;
             next->head      = curr->tail;
             next->tail      = next->head + size;
+            next->size      = size;
             next->length    = size;
 
             // Clear data for all buffers
@@ -251,22 +251,55 @@ namespace lsp
                 return -STATUS_BAD_STATE;
 
             // Estimate number of items to copy
-            size_t last     = lsp_min(off + count, next->length);
-            if (last > next->length)
+            if (off >= next->size)
                 return 0;
+            count           = lsp_min(count, next->size - off);
 
-            // Copy data
+            // Copy data to the frame
             float *dst      = vChannels[channel];
-            count           = last - off;
-            last            = next->head + count;
-            off            += next->head;
-            if (last > nBufCap)
+            size_t head     = next->head + off;
+            if (head >= nBufCap)
+                head           -= nBufCap;
+
+            size_t tail     = head + count;
+            if (tail > nBufCap)
             {
-                dsp::copy(&dst[off], data, nBufCap - off);
-                dsp::copy(dst, &data[nBufCap - off], last - nBufCap);
+                dsp::copy(&dst[head], data, nBufCap - head);
+                dsp::copy(dst, &data[nBufCap - head], tail - nBufCap);
             }
             else
-                dsp::copy(&dst[off], data, count);
+                dsp::copy(&dst[head], data, count);
+
+            return count;
+        }
+
+        ssize_t stream_t::read_frame(uint32_t frame_id, size_t channel, float *data, size_t off, size_t count)
+        {
+            if (channel >= nChannels)
+                return -STATUS_INVALID_VALUE;
+            frame_t *frame = &vFrames[frame_id & (nFrameCap - 1)];
+            if (frame->id != frame_id)
+                return -STATUS_BAD_STATE;
+
+            // Estimate number of items to copy
+            if (off >= frame->size)
+                return -STATUS_EOF;
+            count           = lsp_min(count, frame->size - off);
+
+            // Copy data from the frame
+            float *dst      = vChannels[channel];
+            size_t head     = frame->head + off;
+            if (head >= nBufCap)
+                head           -= nBufCap;
+
+            size_t tail     = head + count;
+            if (tail > nBufCap)
+            {
+                dsp::copy(data, &dst[head], nBufCap - head);
+                dsp::copy(&data[nBufCap - head], dst, tail - nBufCap);
+            }
+            else
+                dsp::copy(data, &dst[head], count);
 
             return count;
         }
@@ -603,323 +636,7 @@ namespace lsp
         }
 
         //-------------------------------------------------------------------------
-        // osc_buffer_t methods
-        osc_buffer_t *osc_buffer_t::create(size_t capacity)
-        {
-            if (capacity % sizeof(uint32_t))
-                return NULL;
-
-            uint8_t *tmp        = reinterpret_cast<uint8_t *>(malloc(0x1000));
-            if (tmp == NULL)
-                return NULL;
-
-            size_t to_alloc     = sizeof(osc_buffer_t) + capacity + DEFAULT_ALIGN;
-            void *data          = NULL;
-            uint8_t *ptr        = alloc_aligned<uint8_t>(data, to_alloc, DEFAULT_ALIGN);
-            if (ptr == NULL)
-            {
-                free(tmp);
-                return NULL;
-            }
-
-            osc_buffer_t *res   = reinterpret_cast<osc_buffer_t *>(ptr);
-            ptr                += align_size(sizeof(osc_buffer_t), DEFAULT_ALIGN);
-
-            res->nSize          = 0;
-            res->nCapacity      = capacity;
-            res->nHead          = 0;
-            res->nTail          = 0;
-            res->pBuffer        = ptr;
-            res->pTempBuf       = tmp;
-            res->nTempSize      = 0x1000;
-            res->pData          = data;
-
-            return res;
-        }
-
-        void osc_buffer_t::destroy(osc_buffer_t *buf)
-        {
-            if (buf->pTempBuf != NULL)
-            {
-                free(buf->pTempBuf);
-                buf->pTempBuf   = NULL;
-            }
-            if ((buf != NULL) && (buf->pData != NULL))
-                free_aligned(buf->pData);
-        }
-
-        status_t osc_buffer_t::submit(const void *data, size_t size)
-        {
-            if ((!size) || (size % sizeof(uint32_t)))
-                return STATUS_BAD_ARGUMENTS;
-
-            // Ensure that there is enough space in buffer
-            size_t oldsize  = nSize;
-            size_t newsize  = oldsize + size + sizeof(uint32_t);
-            if (newsize > nCapacity)
-                return (oldsize == 0) ? STATUS_TOO_BIG : STATUS_OVERFLOW;
-
-            // Store packet size to the buffer and move the tail
-            *(reinterpret_cast<uint32_t *>(&pBuffer[nTail])) = CPU_TO_BE(uint32_t(size));
-            nTail          += sizeof(uint32_t);
-            if (nTail > nCapacity)
-                nTail          -= nCapacity;
-
-            // Store packet data and move the tail
-            size_t head     = nCapacity - nTail;
-            if (size > head)
-            {
-                const uint8_t *src  = reinterpret_cast<const uint8_t *>(data);
-                ::memcpy(&pBuffer[nTail], src, head);
-                ::memcpy(pBuffer, &src[head], size - head);
-            }
-            else
-                ::memcpy(&pBuffer[nTail], data, size);
-
-            nTail          += size;
-            if (nTail > nCapacity)
-                nTail          -= nCapacity;
-
-            // Update the size
-            nSize           = newsize;
-            return STATUS_OK;
-        }
-
-        status_t osc_buffer_t::reserve(size_t size)
-        {
-            if (nTempSize >= size)
-                return STATUS_OK;
-            else if (size > nCapacity)
-                return STATUS_OVERFLOW;
-
-            uint8_t *tmp    = reinterpret_cast<uint8_t *>(realloc(pTempBuf, size));
-            if (tmp == NULL)
-                return STATUS_NO_MEM;
-
-            pTempBuf        = tmp;
-            nTempSize       = size;
-
-            return STATUS_OK;
-        }
-
-        status_t osc_buffer_t::submit(const osc::packet_t *packet)
-        {
-            return (packet != NULL) ? submit(packet->data, packet->size) : STATUS_BAD_ARGUMENTS;
-        }
-
-        void osc_buffer_t::clear()
-        {
-            nSize   = 0;
-            nHead   = 0;
-            nTail   = 0;
-        }
-
-    #define SUBMIT_SIMPLE_IMPL(address, func, ...) \
-            osc::packet_t packet; \
-            osc::forge_t forge; \
-            osc::forge_frame_t sframe, message; \
-            \
-            status_t res = osc::forge_begin_fixed(&sframe, &forge, pTempBuf, nTempSize); \
-            status_t res2; \
-            if (res == STATUS_OK) {\
-                res     = osc::forge_begin_message(&message, &sframe, address); \
-                if (res == STATUS_OK) \
-                    res = osc::func(&message, ## __VA_ARGS__); \
-                osc::forge_end(&message); \
-            } \
-            res2 = osc::forge_end(&sframe); \
-            if (res == STATUS_OK) res = res2; \
-            res2   = osc::forge_close(&packet, &forge); \
-            if (res == STATUS_OK) res = res2; \
-            res2   = osc::forge_destroy(&forge); \
-            if (res == STATUS_OK) res = res2; \
-            return (res == STATUS_OK) ? submit(&packet) : res;
-
-        status_t osc_buffer_t::submit_int32(const char *address, int32_t value)
-        {
-            SUBMIT_SIMPLE_IMPL(address, forge_int32, value);
-        }
-
-        status_t osc_buffer_t::submit_float32(const char *address, float value)
-        {
-            SUBMIT_SIMPLE_IMPL(address, forge_float32, value);
-        }
-
-        status_t osc_buffer_t::submit_string(const char *address, const char *s)
-        {
-            SUBMIT_SIMPLE_IMPL(address, forge_string, s);
-        }
-
-        status_t osc_buffer_t::submit_blob(const char *address, const void *data, size_t bytes)
-        {
-            SUBMIT_SIMPLE_IMPL(address, forge_blob, data, bytes);
-        }
-
-        status_t osc_buffer_t::submit_int64(const char *address, int64_t value)
-        {
-            SUBMIT_SIMPLE_IMPL(address, forge_int64, value);
-        }
-
-        status_t osc_buffer_t::submit_double64(const char *address, double value)
-        {
-            SUBMIT_SIMPLE_IMPL(address, forge_double64, value);
-        }
-
-        status_t osc_buffer_t::submit_time_tag(const char *address, uint64_t value)
-        {
-            SUBMIT_SIMPLE_IMPL(address, forge_time_tag, value);
-        }
-
-        status_t osc_buffer_t::submit_type(const char *address, const char *s)
-        {
-            SUBMIT_SIMPLE_IMPL(address, forge_type, s);
-        }
-
-        status_t osc_buffer_t::submit_symbol(const char *address, const char *s)
-        {
-            SUBMIT_SIMPLE_IMPL(address, forge_symbol, s);
-        }
-
-        status_t osc_buffer_t::submit_ascii(const char *address, char c)
-        {
-            SUBMIT_SIMPLE_IMPL(address, forge_ascii, c);
-        }
-
-        status_t osc_buffer_t::submit_rgba(const char *address, const uint32_t rgba)
-        {
-            SUBMIT_SIMPLE_IMPL(address, forge_rgba, rgba);
-        }
-
-        status_t osc_buffer_t::submit_midi(const char *address, const midi::event_t *event)
-        {
-            SUBMIT_SIMPLE_IMPL(address, forge_midi, event);
-        }
-
-        status_t osc_buffer_t::submit_midi_raw(const char *address, const void *event, size_t bytes)
-        {
-            SUBMIT_SIMPLE_IMPL(address, forge_midi_raw, event, bytes);
-        }
-
-        status_t osc_buffer_t::submit_bool(const char *address, bool value)
-        {
-            SUBMIT_SIMPLE_IMPL(address, forge_bool, value);
-        }
-
-        status_t osc_buffer_t::submit_null(const char *address)
-        {
-            SUBMIT_SIMPLE_IMPL(address, forge_null);
-        }
-
-        status_t osc_buffer_t::submit_inf(const char *address)
-        {
-            SUBMIT_SIMPLE_IMPL(address, forge_inf);
-        }
-
-        #undef SUBMIT_SIMPLE_IMPL
-
-        status_t osc_buffer_t::submit_message(const char *address, const char *params...)
-        {
-            va_list args;
-            va_start(args, params);
-            status_t res = submit_messagev(address, params, args);
-            va_end(args);
-            return res;
-        }
-
-        status_t osc_buffer_t::submit_messagev(const char *address, const char *params, va_list args)
-        {
-            osc::packet_t packet;
-            osc::forge_t forge;
-            osc::forge_frame_t sframe;
-
-            status_t res = osc::forge_begin_fixed(&sframe, &forge, pTempBuf, nTempSize);
-            if (res == STATUS_OK)
-                res     = osc::forge_message(&sframe, address, params, args);
-
-            status_t res2   = osc::forge_end(&sframe);
-            if (res == STATUS_OK)
-                res = res2;
-
-            if (res == STATUS_OK)
-                res         = osc::forge_close(&packet, &forge);
-
-            res2   = osc::forge_destroy(&forge);
-            if (res == STATUS_OK)
-                res = res2;
-
-            return (res == STATUS_OK) ? submit(&packet) : res;
-        }
-
-        status_t osc_buffer_t::fetch(void *data, size_t *size, size_t limit)
-        {
-            if ((data == NULL) || (size == NULL) || (!limit))
-                return STATUS_BAD_ARGUMENTS;
-
-            // There is enough space in the buffer?
-            size_t bufsz    = nSize;
-            if (bufsz < sizeof(uint32_t))
-                return STATUS_NO_DATA;
-
-            // Read size, analyze state of the record and update head
-            size_t psize    = BE_TO_CPU(*(reinterpret_cast<uint32_t *>(&pBuffer[nHead])));
-            if (psize > limit) // We have enough space to store the data?
-                return STATUS_OVERFLOW;
-            if ((psize + sizeof(uint32_t)) > bufsz) // Record is valid?
-                return STATUS_CORRUPTED;
-            *size           = psize;
-            nHead          += sizeof(uint32_t);
-            if (nHead > nCapacity)
-                nHead          -= nCapacity;
-
-            // Copy the buffer contents
-            size_t head     = nCapacity - nHead;
-            if (head < psize)
-            {
-                uint8_t *dst    = reinterpret_cast<uint8_t *>(data);
-                ::memcpy(dst, &pBuffer[nHead], head);
-                ::memcpy(&dst[head], pBuffer, psize - head);
-            }
-            else
-                ::memcpy(data, &pBuffer[nHead], psize);
-
-            nHead          += psize;
-            if (nHead > nCapacity)
-                nHead          -= nCapacity;
-
-            // Decrement size
-            atomic_add(&nSize, -(psize + sizeof(uint32_t)));
-
-            return STATUS_OK;
-        }
-
-        status_t osc_buffer_t::fetch(osc::packet_t *packet, size_t limit)
-        {
-            return (packet != NULL) ? fetch(packet->data, &packet->size, limit) : STATUS_BAD_ARGUMENTS;
-        }
-
-        size_t osc_buffer_t::skip()
-        {
-            if (nSize <= sizeof(uint32_t))
-                return 0;
-
-            size_t bufsz    = nSize;
-            if (bufsz < sizeof(uint32_t))
-                return STATUS_NO_DATA;
-
-            size_t ihead    = nHead;
-            uint32_t *head  = reinterpret_cast<uint32_t *>(&pBuffer[ihead]);
-            size_t psize    = BE_TO_CPU(*head);
-
-            if ((psize + sizeof(uint32_t)) > bufsz) // Record is valid?
-                return 0;
-
-            // Decrement the size and update the head
-            nHead           = (ihead + psize + sizeof(uint32_t)) % nCapacity;
-            atomic_add(&nSize, -(psize + sizeof(uint32_t)));
-
-            return psize;
-        }
-
+        // midi-related methods
         static int compare_midi_events(const void *p1, const void *p2)
         {
             const midi::event_t *e1 = reinterpret_cast<const midi::event_t *>(p1);
@@ -933,8 +650,9 @@ namespace lsp
             if (nEvents > 1)
                 ::qsort(vEvents, nEvents, sizeof(midi::event_t), compare_midi_events);
         }
-    }
-}
+
+    } /* namespace plug */
+} /* namespace lsp */
 
 
 
