@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2021 Linux Studio Plugins Project <https://lsp-plug.in/>
- *           (C) 2021 Vladimir Sadovnikov <sadko4u@gmail.com>
+ * Copyright (C) 2023 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2023 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
  * This file is part of lsp-plugin-fw
  * Created on: 30 июл. 2021 г.
@@ -61,8 +61,11 @@ namespace lsp
                     const LSPString *name   = atts[0];
                     const LSPString *value  = atts[1];
 
-                    if ((name == NULL) || (value == NULL))
-                        continue;
+                    if (value == NULL)
+                    {
+                        lsp_error("Not defined value for attribute '%s'", name->get_native());
+                        return STATUS_CORRUPTED;
+                    }
 
                     if (name->equals_ascii("id"))
                     {
@@ -102,8 +105,8 @@ namespace lsp
                 return res;
             }
 
-        }
-    }
-}
+        } /* namespac xml */
+    } /* namespace ui */
+} /* namespace lsp */
 
 
