@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2021 Linux Studio Plugins Project <https://lsp-plug.in/>
- *           (C) 2021 Vladimir Sadovnikov <sadko4u@gmail.com>
+ * Copyright (C) 2023 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2023 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
  * This file is part of lsp-plugins-expander
  * Created on: 3 авг. 2021 г.
@@ -79,6 +79,7 @@ namespace lsp
 
             static constexpr size_t SC_MODE_DFL             = 1;
             static constexpr size_t SC_SOURCE_DFL           = 0;
+            static constexpr size_t SC_SPLIT_SOURCE_DFL     = 0;
             static constexpr size_t SC_TYPE_DFL             = 0;
 
             static constexpr float  HPF_MIN                 = 10.0f;
@@ -115,8 +116,8 @@ namespace lsp
         extern const meta::plugin_t sc_expander_stereo;
         extern const meta::plugin_t sc_expander_lr;
         extern const meta::plugin_t sc_expander_ms;
-    } // namespace meta
-} // namespace lsp
+    } /* namespace meta */
+} /* namespace lsp */
 
 
 #endif /* PRIVATE_META_EXPANDER_H_ */
