@@ -25,7 +25,7 @@
 
 #define LSP_PLUGINS_EXPANDER_VERSION_MAJOR       1
 #define LSP_PLUGINS_EXPANDER_VERSION_MINOR       0
-#define LSP_PLUGINS_EXPANDER_VERSION_MICRO       19
+#define LSP_PLUGINS_EXPANDER_VERSION_MICRO       20
 
 #define LSP_PLUGINS_EXPANDER_VERSION  \
     LSP_MODULE_VERSION( \
@@ -296,6 +296,7 @@ namespace lsp
         // Expander
         const meta::plugin_t  expander_mono =
         {
+            "Expander Mono",
             "Expander Mono",
             "Expander Mono",
             "E1M",
@@ -320,6 +321,7 @@ namespace lsp
 
         const meta::plugin_t  expander_stereo =
         {
+            "Expander Stereo",
             "Expander Stereo",
             "Expander Stereo",
             "E1S",
@@ -346,6 +348,7 @@ namespace lsp
         {
             "Expander LeftRight",
             "Expander LeftRight",
+            "Expander L/R",
             "E1LR",
             &developers::v_sadovnikov,
             "expander_lr",
@@ -370,6 +373,7 @@ namespace lsp
         {
             "Expander MidSide",
             "Expander MidSide",
+            "Expander M/S",
             "E1MS",
             &developers::v_sadovnikov,
             "expander_ms",
@@ -395,6 +399,7 @@ namespace lsp
         {
             "Sidechain-Expander Mono",
             "Sidechain Expander Mono",
+            "SC Expander Mono",
             "SCE1M",
             &developers::v_sadovnikov,
             "sc_expander_mono",
@@ -419,6 +424,7 @@ namespace lsp
         {
             "Sidechain-Expander Stereo",
             "Sidechain Expander Stereo",
+            "SC Expander Stereo",
             "SCE1S",
             &developers::v_sadovnikov,
             "sc_expander_stereo",
@@ -443,6 +449,7 @@ namespace lsp
         {
             "Sidechain-Expander LeftRight",
             "Sidechain Expander LeftRight",
+            "SC Expander L/R",
             "SCE1LR",
             &developers::v_sadovnikov,
             "sc_expander_lr",
@@ -467,6 +474,7 @@ namespace lsp
         {
             "Sidechain-Expander MidSide",
             "Sidechain Expander MidSide",
+            "SC Expander M/S",
             "SCE1MS",
             &developers::v_sadovnikov,
             "sc_expander_ms",
