@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2021 Linux Studio Plugins Project <https://lsp-plug.in/>
- *           (C) 2021 Vladimir Sadovnikov <sadko4u@gmail.com>
+ * Copyright (C) 2023 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2023 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
  * This file is part of lsp-plugins-impulse-reverb
  * Created on: 3 авг. 2021 г.
@@ -59,10 +59,10 @@ namespace lsp
                         }
 
                         void init(impulse_reverb *base, af_descriptor_t *descr);
-                        virtual ~IRLoader();
+                        virtual ~IRLoader() override;
 
                     public:
-                        virtual status_t    run();
+                        virtual status_t    run() override;
                         void                dump(dspu::IStateDumper *v) const;
                 };
 
@@ -73,10 +73,10 @@ namespace lsp
 
                     public:
                         IRConfigurator(impulse_reverb *base);
-                        virtual ~IRConfigurator();
+                        virtual ~IRConfigurator() override;
 
                     public:
-                        virtual status_t    run();
+                        virtual status_t    run() override;
                         void                dump(dspu::IStateDumper *v) const;
                 };
 
@@ -87,10 +87,10 @@ namespace lsp
 
                     public:
                         explicit GCTask(impulse_reverb *base);
-                        virtual ~GCTask();
+                        virtual ~GCTask() override;
 
                     public:
-                        virtual status_t run();
+                        virtual status_t run() override;
 
                         void        dump(dspu::IStateDumper *v) const;
                 };
@@ -223,23 +223,26 @@ namespace lsp
                 uint8_t                *pData;
                 ipc::IExecutor         *pExecutor;
 
+            protected:
+                void                do_destroy();
+
             public:
                 explicit impulse_reverb(const meta::plugin_t *metadata);
-                virtual ~impulse_reverb();
+                virtual ~impulse_reverb() override;
 
             public:
-                virtual void        init(plug::IWrapper *wrapper, plug::IPort **ports);
-                virtual void        destroy();
+                virtual void        init(plug::IWrapper *wrapper, plug::IPort **ports) override;
+                virtual void        destroy() override;
 
-                virtual void        ui_activated();
-                virtual void        update_settings();
-                virtual void        update_sample_rate(long sr);
+                virtual void        ui_activated() override;
+                virtual void        update_settings() override;
+                virtual void        update_sample_rate(long sr) override;
 
-                virtual void        process(size_t samples);
+                virtual void        process(size_t samples) override;
 
-                void                dump(dspu::IStateDumper *v) const;
+                void                dump(dspu::IStateDumper *v) const override;
         };
-    } // namespace plugins
-} // namespace lsp
+    } /* namespace plugins */
+} /* namespace lsp */
 
 #endif /* PRIVATE_PLUGINS_IMPULSE_REVERB_H_ */
