@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2020 Linux Studio Plugins Project <https://lsp-plug.in/>
- *           (C) 2020 Vladimir Sadovnikov <sadko4u@gmail.com>
+ * Copyright (C) 2023 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2023 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
  * This file is part of lsp-runtime-lib
  * Created on: 16 апр. 2020 г.
@@ -36,9 +36,6 @@ namespace lsp
          */
         class IInAudioStream
         {
-            private:
-                IInAudioStream & operator = (const IInAudioStream &);
-
             public:
                 static const size_t IO_BUF_SIZE         = 0x1000;
 
@@ -90,8 +87,13 @@ namespace lsp
 
             public:
                 explicit IInAudioStream();
+                IInAudioStream(const IInAudioStream &) = delete;
+                IInAudioStream(IInAudioStream &&) = delete;
                 virtual ~IInAudioStream();
 
+                IInAudioStream & operator = (const IInAudioStream &) = delete;
+                IInAudioStream & operator = (IInAudioStream &&) = delete;
+
             public:
                 /**
                  * Check whether audio stream is closed
