@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2020 Linux Studio Plugins Project <https://lsp-plug.in/>
- *           (C) 2020 Vladimir Sadovnikov <sadko4u@gmail.com>
+ * Copyright (C) 2023 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2023 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
  * This file is part of lsp-runtime-lib
  * Created on: 15 окт. 2020 г.
@@ -1051,7 +1051,7 @@ namespace lsp
             {
                 case CMD_PATTERN:
                 {
-                    matcher_t *m = new matcher_t();
+                    matcher_t *m        = new matcher_t();
                     if (m == NULL)
                         return NULL;
 
@@ -1067,7 +1067,7 @@ namespace lsp
 
                 case CMD_ANY:
                 {
-                    any_matcher_t *m = new any_matcher_t();
+                    any_matcher_t *m    = new any_matcher_t();
                     if (m == NULL)
                         return NULL;
 
@@ -1085,7 +1085,7 @@ namespace lsp
 
                 case CMD_ANYPATH:
                 {
-                    matcher_t *m = new matcher_t();
+                    matcher_t *m        = new matcher_t();
                     if (m == NULL)
                         return NULL;
 
@@ -1102,7 +1102,7 @@ namespace lsp
                 case CMD_AND:
                 case CMD_OR:
                 {
-                    bool_matcher_t *m = new bool_matcher_t();
+                    bool_matcher_t *m   = new bool_matcher_t();
                     if (m == NULL)
                         return NULL;
 
@@ -1236,13 +1236,19 @@ namespace lsp
             {
                 // Pattern matcher
                 case M_PATTERN:
-                case M_ANY:
                 case M_ANYPATH:
                 {
                     delete m;
                     break;
                 }
 
+                case M_ANY:
+                {
+                    any_matcher_t *am       = static_cast<any_matcher_t *>(m);
+                    delete am;
+                    break;
+                }
+
                 case M_BOOL:
                 {
                     bool_matcher_t *bm      = static_cast<bool_matcher_t *>(m);
@@ -1384,5 +1390,6 @@ namespace lsp
             lsp::swap(pRoot, dst->pRoot);
             lsp::swap(nFlags, dst->nFlags);
         }
-    }
-}
+
+    } /* namespace io */
+} /* namespace lsp */
