@@ -391,10 +391,192 @@ UTEST_BEGIN("runtime.io", charset)
         }
     }
 
+    void check_latin_lower_upper()
+    {
+        static const lsp_wchar_t lower[] = {
+            'a', 'b', 'c', 'd',
+            'e', 'f', 'g', 'h',
+            'i', 'j', 'k', 'l',
+            'm', 'n', 'o', 'p',
+            'q', 'r', 's', 't',
+            'u', 'v', 'w', 'x',
+            'y', 'z'
+        };
+
+        static const lsp_wchar_t upper[] = {
+            'A', 'B', 'C', 'D',
+            'E', 'F', 'G', 'H',
+            'I', 'J', 'K', 'L',
+            'M', 'N', 'O', 'P',
+            'Q', 'R', 'S', 'T',
+            'U', 'V', 'W', 'X',
+            'Y', 'Z'
+        };
+
+        printf("Testing lsp::to_lower() and lsp::to_upper() for latin character set\n");
+
+        for (size_t i=0; i<sizeof(lower)/sizeof(lower[0]); ++i)
+        {
+            lsp_wchar_t lc = lsp::to_lower(upper[i]);
+            lsp_wchar_t uc = lsp::to_upper(lower[i]);
+
+            UTEST_ASSERT_MSG(
+                lc == lower[i],
+                "Failed conversion of character 0x%x to lower value 0x%x, result value is 0x%x (index=%d)",
+                int(upper[i]), int(lower[i]), int(lc), int(i));
+            UTEST_ASSERT_MSG(
+                uc == upper[i],
+                "Failed conversion of character 0x%x to upper value 0x%x, result value is 0x%x (index=%d)",
+                int(lower[i]), int(upper[i]), int(uc), int(i));
+        }
+    }
+
+    void check_cyrillic_lower_upper()
+    {
+        static const lsp_wchar_t lower[] = {
+            0x450, 0x451, 0x452, 0x453,
+            0x454, 0x455, 0x456, 0x457,
+            0x458, 0x459, 0x45a, 0x45b,
+            0x45c, 0x45d, 0x45e, 0x45f,
+
+            0x430, 0x431, 0x432, 0x433,
+            0x434, 0x435, 0x436, 0x437,
+            0x438, 0x439, 0x43a, 0x43b,
+            0x43c, 0x43d, 0x43e, 0x43f,
+            0x440, 0x441, 0x442, 0x443,
+            0x444, 0x445, 0x446, 0x447,
+            0x448, 0x449, 0x44a, 0x44b,
+            0x44c, 0x44d, 0x44e, 0x44f,
+
+            0x461, 0x463, 0x465, 0x467,
+            0x469, 0x46b, 0x46d, 0x46f,
+            0x471, 0x473, 0x475, 0x477,
+            0x479, 0x47b, 0x47d, 0x47f,
+            0x481,
+
+            0x482, 0x483, 0x484, 0x485,
+            0x486, 0x487, 0x488, 0x489,
+
+            0x48b, 0x48d, 0x48f,
+            0x491, 0x493, 0x495, 0x497,
+            0x499, 0x49b, 0x49d, 0x49f,
+            0x4a1, 0x4a3, 0x4a5, 0x4a7,
+            0x4a9, 0x4ab, 0x4ad, 0x4af,
+            0x4b1, 0x4b3, 0x4b5, 0x4b7,
+            0x4b9, 0x4bb, 0x4bd, 0x4bf,
+            0x4c1, 0x4c3, 0x4c5, 0x4c7,
+            0x4c9, 0x4cb, 0x4cd, 0x4cf,
+            0x4d1, 0x4d3, 0x4d5, 0x4d7,
+            0x4d9, 0x4db, 0x4dd, 0x4df,
+            0x4e1, 0x4e3, 0x4e5, 0x4e7,
+            0x4e9, 0x4eb, 0x4ed, 0x4ef,
+            0x4f1, 0x4f3, 0x4f5, 0x4f7,
+            0x4f9, 0x4fb, 0x4fd, 0x4ff,
+
+            0x501, 0x503, 0x505, 0x507,
+            0x509, 0x50b, 0x50d, 0x50f,
+            0x511, 0x513, 0x515, 0x517,
+            0x519, 0x51b, 0x51d, 0x51f,
+            0x521, 0x523, 0x525, 0x527,
+            0x529, 0x52b, 0x52d, 0x52f,
+
+            0xa641, 0xa643, 0xa645, 0xa647,
+            0xa649, 0xa64b, 0xa64d, 0xa64f,
+            0xa651, 0xa653, 0xa655, 0xa657,
+            0xa659, 0xa65b, 0xa65d, 0xa65f,
+            0xa661, 0xa663, 0xa665, 0xa667,
+            0xa669, 0xa66b, 0xa66d, 0xa66e,
+
+            0xa681, 0xa683, 0xa685, 0xa687,
+            0xa689, 0xa68b, 0xa68d, 0xa68f,
+            0xa691, 0xa693, 0xa695, 0xa697,
+            0xa699, 0xa69b, 0xa69c, 0xa69e,
+        };
+
+        static const lsp_wchar_t upper[] = {
+            0x400, 0x401, 0x402, 0x403,
+            0x404, 0x405, 0x406, 0x407,
+            0x408, 0x409, 0x40a, 0x40b,
+            0x40c, 0x40d, 0x40e, 0x40f,
+
+            0x410, 0x411, 0x412, 0x413,
+            0x414, 0x415, 0x416, 0x417,
+            0x418, 0x419, 0x41a, 0x41b,
+            0x41c, 0x41d, 0x41e, 0x41f,
+            0x420, 0x421, 0x422, 0x423,
+            0x424, 0x425, 0x426, 0x427,
+            0x428, 0x429, 0x42a, 0x42b,
+            0x42c, 0x42d, 0x42e, 0x42f,
+
+            0x460, 0x462, 0x464, 0x466,
+            0x468, 0x46a, 0x46c, 0x46e,
+            0x470, 0x472, 0x474, 0x476,
+            0x478, 0x47a, 0x47c, 0x47e,
+            0x480,
+
+            0x482, 0x483, 0x484, 0x485,
+            0x486, 0x487, 0x488, 0x489,
+
+            0x48a, 0x48c, 0x48e,
+            0x490, 0x492, 0x494, 0x496,
+            0x498, 0x49a, 0x49c, 0x49e,
+            0x4a0, 0x4a2, 0x4a4, 0x4a6,
+            0x4a8, 0x4aa, 0x4ac, 0x4ae,
+            0x4b0, 0x4b2, 0x4b4, 0x4b6,
+            0x4b8, 0x4ba, 0x4bc, 0x4be,
+            0x4c0, 0x4c2, 0x4c4, 0x4c6,
+            0x4c8, 0x4ca, 0x4cc, 0x4ce,
+            0x4d0, 0x4d2, 0x4d4, 0x4d6,
+            0x4d8, 0x4da, 0x4dc, 0x4de,
+            0x4e0, 0x4e2, 0x4e4, 0x4e6,
+            0x4e8, 0x4ea, 0x4ec, 0x4ee,
+            0x4f0, 0x4f2, 0x4f4, 0x4f6,
+            0x4f8, 0x4fa, 0x4fc, 0x4fe,
+
+            0x500, 0x502, 0x504, 0x506,
+            0x508, 0x50a, 0x50c, 0x50e,
+            0x510, 0x512, 0x514, 0x516,
+            0x518, 0x51a, 0x51c, 0x51e,
+            0x520, 0x522, 0x524, 0x526,
+            0x528, 0x52a, 0x52c, 0x52e,
+
+            0xa640, 0xa642, 0xa644, 0xa646,
+            0xa648, 0xa64a, 0xa64c, 0xa64e,
+            0xa650, 0xa652, 0xa654, 0xa656,
+            0xa658, 0xa65a, 0xa65c, 0xa65e,
+            0xa660, 0xa662, 0xa664, 0xa666,
+            0xa668, 0xa66a, 0xa66c, 0xa66e,
+
+            0xa680, 0xa682, 0xa684, 0xa686,
+            0xa688, 0xa68a, 0xa68c, 0xa68e,
+            0xa690, 0xa692, 0xa694, 0xa696,
+            0xa698, 0xa69a, 0xa69c, 0xa69e,
+        };
+
+        printf("Testing lsp::to_lower() and lsp::to_upper() for cyrillic character set\n");
+
+        for (size_t i=0; i<sizeof(lower)/sizeof(lower[0]); ++i)
+        {
+            lsp_wchar_t lc = lsp::to_lower(upper[i]);
+            lsp_wchar_t uc = lsp::to_upper(lower[i]);
+
+            UTEST_ASSERT_MSG(
+                lc == lower[i],
+                "Failed conversion of character 0x%x to lower value 0x%x, result value is 0x%x (index=%d)",
+                int(upper[i]), int(lower[i]), int(lc), int(i));
+            UTEST_ASSERT_MSG(
+                uc == upper[i],
+                "Failed conversion of character 0x%x to upper value 0x%x, result value is 0x%x (index=%d)",
+                int(lower[i]), int(upper[i]), int(uc), int(i));
+        }
+    }
+
     UTEST_MAIN
     {
         check_utf8_to_utfX();
         check_utf16_to_utfX();
+//        check_latin_lower_upper();
+        check_cyrillic_lower_upper();
     }
 UTEST_END;
 
