@@ -22,6 +22,10 @@
 #ifndef LSP_PLUG_IN_TK_WIDGETS_SIMPLE_LISTBOXITEM_H_
 #define LSP_PLUG_IN_TK_WIDGETS_SIMPLE_LISTBOXITEM_H_
 
+#ifndef LSP_PLUG_IN_TK_IMPL
+    #error "use <lsp-plug.in/tk/tk.h>"
+#endif
+
 namespace lsp
 {
     namespace tk
