@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2020 Linux Studio Plugins Project <https://lsp-plug.in/>
- *           (C) 2020 Vladimir Sadovnikov <sadko4u@gmail.com>
+ * Copyright (C) 2023 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2023 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
  * This file is part of lsp-ws-lib
  * Created on: 5 июл. 2022 г.
@@ -63,7 +63,7 @@ namespace lsp
 
             size_t WinDDShared::Release()
             {
-                size_t count = nReferences--;
+                size_t count = --nReferences;
                 if (count == 0)
                     delete this;
                 return count;
@@ -179,7 +179,7 @@ namespace lsp
                     prop.pixelFormat.alphaMode  = D2D1_ALPHA_MODE_PREMULTIPLIED; // D2D1_ALPHA_MODE_STRAIGHT;
                     prop.dpiX                   = dpi_x;
                     prop.dpiY                   = dpi_y;
-                    prop.usage                  = D2D1_RENDER_TARGET_USAGE_GDI_COMPATIBLE;
+                    prop.usage                  = D2D1_RENDER_TARGET_USAGE_NONE;
                     prop.minLevel               = D2D1_FEATURE_LEVEL_DEFAULT;
 
                     hwndProp.hwnd               = pShared->hWindow;
@@ -1218,17 +1218,9 @@ namespace lsp
                 if (bad_state())
                     return;
 
-                // Create the clipping layer
-                ID2D1Layer *layer   = NULL;
-                HRESULT hr          = pDC->CreateLayer(NULL, &layer);
-                if ((FAILED(hr)) || (layer == NULL))
-                    return;
-                lsp_finally{ safe_release(layer); };
-
-                // Apply the layer
-                pDC->PushLayer(
-                    D2D1::LayerParameters(D2D1::RectF(x, y, x+w, y+h)),
-                    layer);
+                pDC->PushAxisAlignedClip(
+                    D2D1::RectF(x, y, x+w, y+h),
+                    D2D1_ANTIALIAS_MODE_PER_PRIMITIVE);
 
                 #ifdef LSP_DEBUG
                 ++ nClipping;
@@ -1249,7 +1241,7 @@ namespace lsp
                 -- nClipping;
             #endif /* LSP_DEBUG */
 
-                pDC->PopLayer();
+                pDC->PopAxisAlignedClip();
             }
 
             IDisplay *WinDDSurface::display()
@@ -1273,7 +1265,7 @@ namespace lsp
                     &desiredSize,
                     &desiredPixelSize,
                     &pixelFormat,
-                    D2D1_COMPATIBLE_RENDER_TARGET_OPTIONS_GDI_COMPATIBLE, // options
+                    D2D1_COMPATIBLE_RENDER_TARGET_OPTIONS_NONE, // options
                     &dc);
                 if (FAILED(hr))
                     return NULL;
@@ -1307,7 +1299,7 @@ namespace lsp
                     &desiredSize,
                     &desiredPixelSize,
                     &pixelFormat,
-                    D2D1_COMPATIBLE_RENDER_TARGET_OPTIONS_GDI_COMPATIBLE,
+                    D2D1_COMPATIBLE_RENDER_TARGET_OPTIONS_NONE,
                     &dc);
                 if (FAILED(hr))
                     return NULL;
@@ -1489,13 +1481,23 @@ namespace lsp
                     out_text(f, color, x, y, &tmp, 0, tmp.length());
             }
 
-            bool WinDDSurface::try_out_text(IDWriteFontCollection *fc, IDWriteFontFamily *ff, const WCHAR *family, const Font &f, const Color &color, float x, float y, const WCHAR *text, size_t length)
+            bool WinDDSurface::try_out_text(IDWriteFontCollection *fc, IDWriteFontFamily *ff, const WCHAR *family, const Font &f, const Color &color, float x, float y, const lsp_wchar_t *text, size_t length)
             {
-                // Create text layout
-                IDWriteTextLayout *tl   = pShared->pDisplay->create_text_layout(f, family, fc, ff, text, length);
-                if (tl == NULL)
+                // Get font face
+                IDWriteFontFace *face   = pShared->pDisplay->get_font_face(f, ff);
+                if (face == NULL)
                     return false;
-                lsp_finally{ safe_release(tl); };
+                lsp_finally { safe_release(face); };
+
+                // Obtain font metrics
+                DWRITE_FONT_METRICS fm;
+                face->GetMetrics(&fm);
+
+                // Create glyph run
+                win::glyph_run_t *run   = pShared->pDisplay->make_glyph_run(f, face, &fm, text, length);
+                if (run == NULL)
+                    return false;
+                lsp_finally { free(run); };
 
                 // Create brush
                 ID2D1SolidColorBrush *brush = NULL;
@@ -1517,11 +1519,33 @@ namespace lsp
                     default:
                         break;
                 }
-                pDC->DrawTextLayout(
-                    D2D1::Point2F(x, y),
-                    tl,
+
+                pDC->DrawGlyphRun(
+                    D2D1_POINT_2F{x, y},
+                    run->run,
                     brush,
-                    D2D1_DRAW_TEXT_OPTIONS_NONE);
+                    DWRITE_MEASURING_MODE_NATURAL);
+
+                if (f.is_underline())
+                {
+                    ws::text_parameters_t tp;
+                    calc_text_metrics(f, &tp, &fm, run->metrics, length);
+
+                    float scale = f.size() / float(fm.designUnitsPerEm);
+                    float k     = f.bold() ? 0.6f : 0.5f;
+                    float ypos  = y - fm.underlinePosition * scale;
+                    float thick = k * fm.underlineThickness * scale;
+
+                    pDC->FillRectangle(
+                        D2D1_RECT_F {
+                            x,
+                            ypos - thick,
+                            x + tp.Width,
+                            ypos + thick
+                        },
+                        brush);
+                }
+
                 pDC->SetTextAntialiasMode(antialias);
 
                 return true;
@@ -1531,10 +1555,11 @@ namespace lsp
             {
                 if (bad_state())
                     return;
-                const WCHAR *pText = (text != NULL) ? reinterpret_cast<const WCHAR *>(text->get_utf16(first, last)) : NULL;
-                if (pText == NULL)
+                if ((first < 0) || (last < 0) || (first >= last))
                     return;
-                size_t length = text->range_length(first, last);
+
+                size_t range    = text->range_length(first, last);
+                const lsp_wchar_t *data = text->characters();
 
                 // Obtain the font family
                 LSPString family_name;
@@ -1544,12 +1569,12 @@ namespace lsp
 
                 if (custom != NULL)
                 {
-                    if (try_out_text(custom->collection, custom->family, custom->wname, f, color, x, y, pText, length))
+                    if (try_out_text(custom->collection, custom->family, custom->wname, f, color, x, y, &data[first], range))
                         return;
                 }
                 if (ff != NULL)
                 {
-                    if (try_out_text(NULL, ff, family_name.get_utf16(), f, color, x, y, pText, length))
+                    if (try_out_text(NULL, ff, family_name.get_utf16(), f, color, x, y, &data[first], range))
                         return;
                 }
             }
@@ -1568,18 +1593,22 @@ namespace lsp
                 return out_text_relative(f, color, x, y, dx, dy, &tmp, 0, tmp.length());
             }
 
-            bool WinDDSurface::try_out_text_relative(IDWriteFontCollection *fc, IDWriteFontFamily *ff, const WCHAR *family, const Font &f, const Color &color, float x, float y, float dx, float dy, const WCHAR *text, size_t length)
+            bool WinDDSurface::try_out_text_relative(IDWriteFontCollection *fc, IDWriteFontFamily *ff, const WCHAR *family, const Font &f, const Color &color, float x, float y, float dx, float dy, const lsp_wchar_t *text, size_t length)
             {
+                IDWriteFontFace *face   = pShared->pDisplay->get_font_face(f, ff);
+                if (face == NULL)
+                    return false;
+                lsp_finally { safe_release(face); };
+
                 // Obtain font metrics
                 DWRITE_FONT_METRICS fm;
-                if (!pShared->pDisplay->get_font_metrics(f, ff, &fm))
-                    return false;
+                face->GetMetrics(&fm);
 
-                // Create text layout
-                IDWriteTextLayout *tl   = pShared->pDisplay->create_text_layout(f, family, fc, ff, text, length);
-                if (tl == NULL)
+                // Create glyph run
+                win::glyph_run_t *run   = pShared->pDisplay->make_glyph_run(f, face, &fm, text, length);
+                if (run == NULL)
                     return false;
-                lsp_finally{ safe_release(tl); };
+                lsp_finally { free(run); };
 
                 // Create brush
                 ID2D1SolidColorBrush *brush = NULL;
@@ -1587,19 +1616,6 @@ namespace lsp
                     return false;
                 lsp_finally{ safe_release(brush); };
 
-                // Get text layout metrics and font metrics
-                DWRITE_TEXT_METRICS tm;
-                tl->GetMetrics(&tm);
-
-                // Compute the text position
-                float ratio     = f.size() / float(fm.designUnitsPerEm);
-                float height    = (fm.ascent + fm.descent + fm.lineGap) * ratio;
-                float xbearing  = (f.italic()) ? sinf(0.033f * M_PI) * height : 0.0f;
-                float r_w       = tm.width;
-                float r_h       = fm.capHeight * ratio;
-                float fx        = x - xbearing - r_w * 0.5f + (r_w + 4.0f) * 0.5f * dx;
-                float fy        = y + r_h * 0.5f - (r_h + 4.0f) * 0.5f * dy;
-
                 // Draw the text
                 D2D1_TEXT_ANTIALIAS_MODE antialias = pDC->GetTextAntialiasMode();
                 switch (f.antialias())
@@ -1615,11 +1631,37 @@ namespace lsp
                         break;
                 }
 
-                pDC->DrawTextLayout(
-                    D2D1::Point2F(fx, fy),
-                    tl,
+                ws::text_parameters_t tp;
+                calc_text_metrics(f, &tp, &fm, run->metrics, length);
+
+                float r_w       = tp.Width;
+                float r_h       = tp.Height;
+                float fx        = x - tp.XBearing - r_w * 0.5f + (r_w + 4.0f) * 0.5f * dx;
+                float fy        = y + r_h * 0.5f - (r_h + 4.0f) * 0.5f * dy;
+
+                pDC->DrawGlyphRun(
+                    D2D1_POINT_2F{fx, fy},
+                    run->run,
                     brush,
-                    D2D1_DRAW_TEXT_OPTIONS_NONE);
+                    DWRITE_MEASURING_MODE_NATURAL);
+
+                if (f.is_underline())
+                {
+                    float scale = f.size() / float(fm.designUnitsPerEm);
+                    float k     = f.bold() ? 0.6f : 0.5f;
+                    float ypos  = fy - fm.underlinePosition * scale;
+                    float thick = k * fm.underlineThickness * scale;
+
+                    pDC->FillRectangle(
+                        D2D1_RECT_F {
+                            fx,
+                            ypos - thick,
+                            fx + tp.Width,
+                            ypos + thick
+                        },
+                        brush);
+                }
+
                 pDC->SetTextAntialiasMode(antialias);
 
                 return true;
@@ -1629,10 +1671,11 @@ namespace lsp
             {
                 if (bad_state())
                     return;
-                const WCHAR *pText = (text != NULL) ? reinterpret_cast<const WCHAR *>(text->get_utf16(first, last)) : NULL;
-                if (pText == NULL)
+                if ((first < 0) || (last < 0) || (first >= last))
                     return;
-                size_t length = text->range_length(first, last);
+
+                size_t range    = text->range_length(first, last);
+                const lsp_wchar_t *data = text->characters();
 
                 // Obtain the font family
                 LSPString family_name;
@@ -1643,12 +1686,12 @@ namespace lsp
 
                 if (custom != NULL)
                 {
-                    if (try_out_text_relative(custom->collection, custom->family, custom->wname, f, color, x, y, dx, dy, pText, length))
+                    if (try_out_text_relative(custom->collection, custom->family, custom->wname, f, color, x, y, dx, dy, &data[first], range))
                         return;
                 }
                 if (ff != NULL)
                 {
-                    if (try_out_text_relative(NULL, ff, family_name.get_utf16(), f, color, x, y, dx, dy, pText, length))
+                    if (try_out_text_relative(NULL, ff, family_name.get_utf16(), f, color, x, y, dx, dy, &data[first], range))
                         return;
                 }
             }
